<?php

namespace ConsentMagicPro;

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * CS_Meta_LDU
 * Meta Limited Data Use
 */
class CS_Google_Consent_Mode {

	private static $_instance = null;

	public $loader;

	private $enable_blocking = false;

	private $consent_mode = null;

	private $ad_storage = false;

	private $analytics_storage = false;

	private $ad_user_data = false;

	private $ad_personalization = false;

	/**
	 * $_instance CS_Google_Consent_Mode
	 * @return CS_Google_Consent_Mode|null
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	private function __construct() {
		if ( is_plugin_activated() ) {
			$this->enable_blocking = ConsentMagic::$check_disable_cm && ConsentMagic()->getOption( 'cs_block_pre_defined_scripts' ) && ConsentMagic()->getOption( 'cs_plugin_activation' ) && ConsentMagic()->getOption( 'cs_script_blocking_enabled' );

			if ( $this->enabled_google_consent_mode() ) {
				$this->loader = new CS_Loader();
				$this->loader->add_action( 'init', $this, 'add_google_consent_mode', 2 );
				$this->loader->run();
			}
		}
	}

	public function enabled_blocking() {
		return $this->enable_blocking;
	}

	/**
	 * Add google consent mode
	 * @return void
	 */
	public function add_google_consent_mode() {
		if ( $this->enabled_blocking() ) {
			$active_rule_name         = ConsentMagic()->get_active_rule_name();
			$analytics_storage        = $ad_storage = $ad_user_data = $ad_personalization = 'granted';
			$analytics_storage_ignore = $ad_storage_ignore = $ad_user_data_ignore = $ad_personalization_ignore = false;

			$category = get_term_by( 'slug', ConsentMagic()->getOption( 'cs_block_analytics_storage_scripts_cat' ), 'cs-cookies-category' );
			if ( $category ) {
				$category_id = $category->term_id;
				if ( $active_rule_name == 'iab' ) {
					$category_id = CS_IAB_Integration()->check_enabled_purpose_by_category( $category_id ) ? $category_id : 0;
				}
				$analytics_storage        = $this->get_advanced_consent_mode_value( $category_id )[ 'value' ];
				$analytics_storage_ignore = get_term_meta( $category_id, 'cs_ignore_this_category', true ) == 1;
			}

			$category = get_term_by( 'slug', ConsentMagic()->getOption( 'cs_block_ad_storage_scripts_cat' ), 'cs-cookies-category' );
			if ( $category ) {
				$category_id = $category->term_id;
				if ( $active_rule_name == 'iab' ) {
					$category_id = CS_IAB_Integration()->check_enabled_purpose_by_category( $category_id ) ? $category_id : 0;
				}
				$ad_storage        = $this->get_advanced_consent_mode_value( $category_id )[ 'value' ];
				$ad_storage_ignore = get_term_meta( $category_id, 'cs_ignore_this_category', true ) == 1;
			}

			$category = get_term_by( 'slug', ConsentMagic()->getOption( 'cs_block_ad_user_data_scripts_cat' ), 'cs-cookies-category' );
			if ( $category ) {
				$category_id = $category->term_id;
				if ( $active_rule_name == 'iab' ) {
					$category_id = CS_IAB_Integration()->check_enabled_purpose_by_category( $category_id ) ? $category_id : 0;
				}
				$ad_user_data        = $this->get_advanced_consent_mode_value( $category_id )[ 'value' ];
				$ad_user_data_ignore = get_term_meta( $category_id, 'cs_ignore_this_category', true ) == 1;
			}

			$category = get_term_by( 'slug', ConsentMagic()->getOption( 'cs_block_ad_personalization_scripts_cat' ), 'cs-cookies-category' );
			if ( $category ) {
				$category_id = $category->term_id;
				if ( $active_rule_name == 'iab' ) {
					$category_id = CS_IAB_Integration()->check_enabled_purpose_by_category( $category_id ) ? $category_id : 0;
				}
				$ad_personalization        = $this->get_advanced_consent_mode_value( $category_id )[ 'value' ];
				$ad_personalization_ignore = get_term_meta( $category_id, 'cs_ignore_this_category', true ) == 1;
			}

			$blocking_enabled         = ConsentMagic()->ready_to_run() && ConsentMagic::$check_disable_cm && ConsentMagic()->getOption( 'cs_block_pre_defined_scripts' ) && ConsentMagic()->getOption( 'cs_plugin_activation' ) && ConsentMagic()->getOption( 'cs_script_blocking_enabled' );
			$this->ad_storage         = (bool) apply_filters( 'cm_ad_storage_mode', $blocking_enabled && !$ad_storage_ignore && ConsentMagic()->getOption( 'cs_block_ad_storage_scripts' ) );
			$this->analytics_storage  = (bool) apply_filters( 'cm_analytics_storage_mode', $blocking_enabled && !$analytics_storage_ignore && ConsentMagic()->getOption( 'cs_block_analytics_storage_scripts' ) );
			$this->ad_user_data       = (bool) apply_filters( 'cm_ad_user_data_mode', $blocking_enabled && !$ad_user_data_ignore && ConsentMagic()->getOption( 'cs_block_ad_user_data_scripts' ) );
			$this->ad_personalization = (bool) apply_filters( 'cm_ad_personalization_mode', $blocking_enabled && !$ad_personalization_ignore && ConsentMagic()->getOption( 'cs_block_ad_personalization_scripts' ) );

		} else {
			$this->ad_storage         = true;
			$this->analytics_storage  = true;
			$this->ad_user_data       = true;
			$this->ad_personalization = true;
			$analytics_storage        = $ad_storage = $ad_user_data = $ad_personalization = 'granted';
		}

		add_filter( 'cm_google_consent_mode', function() use ( $analytics_storage, $ad_storage, $ad_user_data, $ad_personalization ) {
			return array(
				'analytics_storage'  => array(
					'enabled' => $this->analytics_storage,
					'value'   => $analytics_storage,
				),
				'ad_storage'         => array(
					'enabled' => $this->ad_storage,
					'value'   => $ad_storage,
				),
				'ad_user_data'       => array(
					'enabled' => $this->ad_user_data,
					'value'   => $ad_user_data,
				),
				'ad_personalization' => array(
					'enabled' => $this->ad_personalization,
					'value'   => $ad_personalization,
				),
			);
		} );
	}

	/**
	 * Get advanced consent mode value
	 * @param $cat_id
	 * @return array
	 */
	public function get_advanced_consent_mode_value( $cat_id ) {

		$active_rule_id = ConsentMagic()->get_active_rule_id();
		$ignore         = get_term_meta( $cat_id, 'cs_ignore_this_category', true );
		$necessary      = get_term_by( 'slug', 'necessary', 'cs-cookies-category' );
		$necessary_id   = $necessary->term_id;

		if ( empty( $active_rule_id ) || $cat_id == 0 || $ignore == 1 || $cat_id == $necessary_id ) {
			return array(
				'status' => false,
				'value'  => 'granted'
			);
		}

		$cs_type            = get_post_meta( $active_rule_id, '_cs_type', true );
		$analytics_cat_id   = get_option( 'analytics_cat_id' );
		$cs_track_analytics = get_post_meta( $active_rule_id, '_cs_track_analytics', true );
		$test_prefix        = false;
		$check              = true;

		if ( ConsentMagic()->getOption( 'cs_test_mode' ) ) {
			$test_prefix = '_test';
		}
		$viewed_cookie   = "cs_viewed_cookie_policy" . $test_prefix;
		$category_cookie = "cs_enabled_cookie_term" . $test_prefix . '_' . $cat_id;
		$native_scripts  = get_post_meta( $active_rule_id, '_cs_native_scripts', true );

		if ( isset( $_COOKIE[ 'cs_consent_string' ] ) && $cs_type == 'iab' && $native_scripts == 0 ) {
			try {
				$iab_string = json_decode( base64_decode( sanitize_text_field( $_COOKIE[ 'cs_consent_string' ] ) ), false );
				$purposes   = $iab_string->purposes;
				$iab_cat    = get_term_meta( $cat_id, '_cs_iab_cat', true );
				if ( !empty( $iab_cat ) ) {
					if ( $iab_cat != 0 ) {
						$v     = substr( $purposes, $iab_cat - 1, 1 );
						$check = ( $v !== '' ? $v : 1 ) == 0;
					} else {
						$check = false;
					}
				}
			} catch ( \Exception $e ) {
				error_log( 'Error: ' . $e->getMessage() );
			}
		} else {
			if ( isset( $_COOKIE[ $category_cookie ] ) && isset( $_COOKIE[ $viewed_cookie ] ) ) {
				if ( $_COOKIE[ $category_cookie ] == 'yes' && $_COOKIE[ $viewed_cookie ] == 'yes' ) {
					$check = false; //allowed by user then false
				}
			} else {
				if ( $cs_type == 'iab' || $cs_type == 'ask_before_tracking' ) {
					if ( (int) $cs_track_analytics === 1 && $analytics_cat_id == $cat_id ) {
						$check = false; //track analytics
					}
				} else {
					$check = false; //this is rule "inform_and_opiout" OR "just_inform"
				}
			}
		}

		return array(
			'status' => $check,
			'value'  => $check ? 'denied' : 'granted'
		);
	}

	public function enabled_google_consent_mode() {

		if ( $this->consent_mode !== null ) {
			return $this->consent_mode;
		}

		$consent_mode   = false;
		$active_rule_id = ConsentMagic()->get_active_rule_id();

		if ( ConsentMagic()->ready_to_run() && !empty( $active_rule_id ) ) {
			$cs_type = get_post_meta( $active_rule_id, '_cs_type', true );
			if ( $cs_type == 'ask_before_tracking' || $cs_type == 'inform_and_opiout' || $cs_type == 'iab' ) {
				$consent_mode = get_post_meta( $active_rule_id, '_cs_google_consent_mode', true );
			}
		}
		$this->consent_mode = $consent_mode;

		return $consent_mode;
	}
}

/**
 * @return CS_Google_Consent_Mode
 */
function CS_Google_Consent_Mode(): CS_Google_Consent_Mode {
	return CS_Google_Consent_Mode::instance();
}