( function ( $ ) {
    'use strict';

    /**
     * All of the code for your admin-facing JavaScript source
     * should reside in this file.
     *
     * Note: It has been assumed you will write jQuery code here, so the
     * $ function reference has been prepared for usage within the scope
     * of this function.
     *
     * This enables you to define handlers, for when the DOM is ready:
     *
     * $(function() {
     *
     * });
     *
     * When the window is loaded:
     *
     * $( window ).load(function() {
     *
     * });
     *
     * ...and/or other possibilities.
     *
     * Ideally, it is not considered best practise to attach more than a
     * single DOM-ready or window-load handler for a particular page.
     * Although scripts in the WordPress core, Plugins and Themes may be
     * practising this, we should strive to set a better example in our own work.
     */
    $( function () {

        let cs_settings_form = $( '#cs_settings_form' ),
            cs_step_form = $( '#cs_step_form' ),
            step_url = cs_step_form.attr( 'action' ),
            cs_design_form = $( '#cs_design_form' ),
            cs_script_form = $( '#cs_script_form' ),
            cs_cookie_form = $( '#cs_cookie_form' ),
            cs_new_rule_form = $( '#cs_new_rule_form' ),
            cs_settings_tab_form = $( '#cs_settings_tab_form' ),
            url = cs_settings_form.attr( 'action' ),
            cs_nav_tab = $( '.nav-tab' ),
            link_to_nav = $( '.link-to-nav-tab' ),
            switcher = $( '.custom-switch-input' ),
            select_target = $( '#_cs_general_target' ),
            select_term_lang = $( '.form-control-term-lang' ),
            wpnonce = $( '#_wpnonce' ).val();

        $( ".portlet_column" ).sortable( {
            connectWith: ".portlet_column",
            handle: ".portlet-header",
            cancel: ".portlet-toggle",
            placeholder: "ui-state-highlight",
        } );

        $( ".portlet" )
            .addClass( "ui-widget ui-widget-content ui-helper-clearfix ui-corner-all" )
            .find( ".portlet-header" )
            .addClass( "ui-widget-header ui-corner-all" )
            .prepend( "<span class='icon-down btn btn-link portlet-toggle'></span>" );

        $( ".portlet-toggle" ).on( "click", function () {
            let icon = $( this );
            icon.toggleClass( "icon-down icon-up-arrow" );
            icon.closest( ".portlet" ).find( ".portlet-content" ).toggle();
        } );

        let itemList = $( ".portlet_column" );
        itemList.sortable( {
            update: function ( event, ui ) {
                $.ajax( {
                    url: cmpro_ajax.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'item_sort',
                        order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                        _wpnonce: wpnonce
                    },
                    success: function ( response ) {
                        if ( !response.success ) {
                            console.log( 'There was an error saving the updates' );
                        }
                    }
                } );
            },
            change: function ( event, ui ) {
                $.ajax( {
                    url: cmpro_ajax.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'item_sort', // Tell WordPress how to handle this ajax request
                        order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                        _wpnonce: wpnonce
                    },
                    success: function ( response ) {
                        if ( !response.success ) {
                            console.log( 'There was an error saving the updates' );
                        }
                    }
                } );
            }
        } );

        $( 'select' ).cs_select2();

        //Target matcher function for search countries
        function target_matcher( params, data ) {
            let search = $.trim( params.term ).toLowerCase();

            if ( search === '' ) {
                $( '.cs_select2-results__options' ).removeClass( 'cs_select2-results__searched' );
                return data;
            } else {
                $( '.cs_select2-results__options' ).addClass( 'cs_select2-results__searched' );
                let name = data.text.toLowerCase();
                if ( data.id === 'GDPR' || data.id === 'NONGDPR' ) {
                    return null;
                }

                if ( name.indexOf( search ) > -1 ) {
                    return data;
                }

                if ( data.children && data.children.length > 0 ) {
                    const filteredChildren = data.children.filter( child =>
                        child.text.toLowerCase().indexOf( search ) > -1
                    );

                    if ( filteredChildren.length > 0 ) {
                        const newData = $.extend( {}, data, true );
                        newData.children = filteredChildren;
                        return newData;
                    }
                }
            }
            return null;
        }

        select_target.cs_select2( {
            closeOnSelect: false,
            dropdownCssClass: "cs_location",
            allowClear: false,
            matcher: target_matcher,
            templateResult: formatResult,

        } ).on( 'cs_select2:open', () => {
            $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to hide locations list' );
            $( ".cs_select2-results:not(:has(a))" ).prepend( '<div class="cs_options_button_group">' +
                '<a href="#" class="selectAll">Select All</a>' +
                '<a href="#" class="clearAll">Clear All</a>' +
                '</div>' );
        } ).on( 'cs_select2:close', ( e ) => {
            $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to show locations list' );
        } ).on( 'cs_select2:select', function ( e ) {
            let $select = $( this ),
                data = e.params.data,
                pid = data.element.attributes[ 0 ].value;
            if ( data.id == 'GDPR' || data.id == 'NONGDPR' ) {
                $select.find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).trigger( "change" );
                $select.cs_select2( 'destroy' ).find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).end().cs_select2( {
                    closeOnSelect: false,
                    dropdownCssClass: "cs_location",
                    allowClear: false,
                    matcher: target_matcher,
                    templateResult: formatResult,
                } );

                if ( data.id == 'GDPR' || data.id == 'NONGDPR' ) {
                    let childIds = $.grep( e.target.options, function ( option ) {
                        return $( option ).data( 'pid' ) == pid;
                    } );
                    childIds = $.map( childIds, function ( option ) {
                        return option.value;
                    } );

                    $select.val( data.id );

                    $select.val( $select.cs_select2( 'val' ).concat( childIds ) ).find( 'option:selected' ).prop( 'disabled', true ).trigger( "change" );
                    $select.trigger( "change" );
                    update_target( $( this ), true, false, data.id === 'NONGDPR' );
                }
                $select.cs_select2( "open" );
            } else {
                update_target( $( this ), data.id === 'US', true, true );
            }

        } ).on( 'cs_select2:unselect', function ( e ) {
            let $select = $( this );
            update_target( $( this ), e.params.data.id === 'US', true, false );
            $select.trigger( "change" );
        } );

        function formatResult( data ) {
            if ( !data.id ) {
                return data.text;
            }

            let $result = $( `<span>${ data.text }</span>` );

            if ( data.element ) {
                const dataset = data.element.dataset;
                Object.keys( dataset ).forEach( key => {
                    $result.attr( `data-${ key }`, dataset[ key ] );
                } );
            }

            return $result;
        }

        $( '.cs_select2-search__field' ).attr( 'placeholder', 'Click to show locations list' );

        $( document ).on( 'click', '.clearAll', function ( e ) {
            $( this ).addClass( 'active' );
            select_target.cs_select2( 'destroy' ).find( 'option' ).prop( 'disabled', false ).prop( 'selected', false ).end().cs_select2( {
                closeOnSelect: false,
                dropdownCssClass: "cs_location",
                allowClear: false,
                matcher: target_matcher,
                templateResult: formatResult,
            } );
            select_target.cs_select2( "open" );

            update_target( select_target, true, false, false );
        } );

        select_target.on( 'cs_select2:clear', function ( e ) {
            $( '.selectGDPR, .selectnonGDPR' ).removeClass( 'active' );
            $( "#_cs_general_target option" ).each( function () {
                $( this ).prop( 'disabled', false );
                $( this ).prop( 'selected', false );
            } );
        } );

        $( document ).on( 'click', '.selectAll', function ( e ) {
            select_target.cs_select2( 'destroy' ).find( 'option' ).prop( 'selected', 'selected' ).end().cs_select2( {
                closeOnSelect: false,
                dropdownCssClass: "cs_location",
                allowClear: false,
                matcher: target_matcher,
                templateResult: formatResult,
            } );
            $( '.selectAll' ).addClass( 'active' );
            select_target.cs_select2( "open" );

            update_target( select_target, true, false, true );
        } );

        switcher.on( 'click', function () {
            if ( $( this ).is( ':checked' ) ) {
                $( this ).closest( '.custom-switch__parent_wrap' ).removeClass( 'not-active' );
                $( this ).closest( '.scripts-list-item' ).removeClass( 'not-active' );
            } else {
                $( this ).closest( '.custom-switch__parent_wrap' ).addClass( 'not-active' );
                $( this ).closest( '.scripts-list-item' ).addClass( 'not-active' );
            }
        } );

        $( '.js-control .custom-switch-input' ).on( 'change', function () {
            let active = 0,
                status = 'draft';
            if ( $( this ).is( ':checked' ) ) {
                active = 1;
                status = 'publish';
            }
            let parent = $( this ).closest( '.js-control' ),
                id = parent.data( 'id' );
            if ( status == 'publish' ) {
                $( this ).closest( '.rules-wrap' ).removeClass( 'draft' );
            } else {
                $( this ).closest( '.rules-wrap' ).addClass( 'draft' );
            }

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'predefined_rule_enable_update',
                    id: id,
                    active: active,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    console.log( 'rule updated', response.data );
                    $.ajax( {
                        url: cmpro_ajax.ajaxurl,
                        type: 'POST',
                        data: {
                            action: 'item_sort', // Tell WordPress how to handle this ajax request
                            order: itemList.sortable( 'toArray' ).toString(), // Passes ID's of list items in  1,3,2 format
                            _wpnonce: wpnonce
                        },
                        success: function ( response ) {
                            if ( !response.success ) {
                                console.log( 'There was an error saving the updates' );
                            }
                        }
                    } );
                },
                error: function () {  // This can be expanded to provide more information
                    console.log( 'There was an error saving the updates' );
                }
            } );
        } );

        $( '.js-ip-rule-control .custom-switch-input' ).on( 'change', function () {
            let active = 0;
            if ( $( this ).is( ':checked' ) ) {
                active = 1;
            }
            let parent = $( this ).closest( '.js-ip-rule-control' ),
                id = parent.data( 'id' );

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'no_ip_rule_update',
                    id: id,
                    active: active,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    console.log( 'rule updated', response.data );
                },
                error: function () {  // This can be expanded to provide more information
                    console.log( 'There was an error saving the updates' );
                }
            } );
        } );

        // Export
        $( '.export_proof_consent' ).on( 'click', function ( e ) {
            e.preventDefault();
            cs_export_proof_consent();
        } );

        // Export
        $( '.export_proof_consent_popup' ).on( 'click', function ( e ) {
            e.preventDefault();
            cs_export_proof_consent( true );
        } );

        function cs_export_proof_consent( submit = false, limit, offset ) {
            if ( typeof ( offset ) === 'undefined' ) offset = 0;
            if ( typeof ( limit ) === 'undefined' ) limit = 'undefined';
            let post_data = {
                'limit': limit,
                'offset': offset,
                'submit': submit,
                nonce_code: cmpro_ajax.nonce,
                action: 'cs_export_proof_consent'
            };
            if ( offset == 0 )
                $( '.popup' ).html( '<div class="msg">Export processing...</div>' ).show();
            $.ajax( {
                type: "POST",
                data: post_data,
                url: cmpro_ajax.ajaxurl,
                success: function ( response ) {
                    console.log( 'Processing, do not cancel' );
                    if ( response.loop == 1 ) {
                        cs_export_proof_consent( submit, response.limit, response.offset );
                        $( '.popup' ).addClass( 'success' ).html( '<div class="msg">Exported ' + response.offset + ' items</div>' );
                    }
                    if ( response.loop == 0 ) {
                        $( '.popup' ).addClass( 'success' ).html( '<div class="msg">Exported completed</div>' );
                        let valFileDownloadPath = response.file_url;
                        window.open( valFileDownloadPath, '_blank' );
                        if ( $( '.cs_delete_proof_consent_wrap' ).length > 0 ) {
                            $( '.cs_delete_proof_consent_wrap' ).hide();
                        }

                        $.ajax( {
                            url: cmpro_ajax.ajaxurl,
                            type: 'POST',
                            data: {
                                action: 'cs_export_proof_consent_done',
                                nonce_code: cmpro_ajax.nonce
                            },
                            error: function ( response ) {
                                console.log( 'ERROR' );
                                console.log( response );
                            }
                        } )
                    }
                },
                error: function ( response ) {
                    console.log( 'ERROR' );
                    console.log( response );
                    $( '.popup' ).addClass( 'error' ).html( '<div class="msg">Oops, something wrong</div>' ).show();
                    setTimeout( function () {
                        $( '.popup' ).removeClass( 'error' ).hide();
                    }, 1500 );
                }
            } );
        }

        $( '.color-field' ).wpColorPicker();

        $( '.card-collapse' ).on( 'click', function () {
            let e = $( this ).closest( ".card" ).find( ".card-body" ),
                i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.hide().removeClass( "show" ) : e.show().addClass( "show" );
            i.hasClass( "icon-up-arrow" ) ? i.removeClass( "icon-up-arrow" ).addClass( "icon-down" ) : i.removeClass( "icon-down" ).addClass( "icon-up-arrow" );
        } );

        $( '.sub-card-collapse' ).on( 'click', function () {
            let e = $( this ).closest( ".sub-card" ).find( ".sub-card-body" ),
                i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.hide().removeClass( "show" ) : e.show().addClass( "show" );
            i.hasClass( "icon-up-arrow" ) ? i.removeClass( "icon-up-arrow" ).addClass( "icon-down" ) : i.removeClass( "icon-down" ).addClass( "icon-up-arrow" );
        } );

        $( document ).on( 'click', '.cs-modal-close, .preview_wrap .cs_popup_overlay, .preview_wrap .cs_action_btn, .preview_wrap .cs_action_purposes_btn', function ( e ) {
            e.preventDefault();
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' );
            jQuery( 'body' ).removeClass( "cs-barmodal-open cs-modal-open" );
            popup.find( '.cs_settings_popup' ).removeClass( 'cs-show cs-blowup' );
            popup.find( '.cs_settings_popup' ).addClass( 'cs-out' );
            popup.find( ".cs-settings-overlay" ).removeClass( "cs-show" );
            popup.find( ".cs-popupbar-overlay" ).removeClass( "cs-show" );

            let info_bar = popup.find( ".cs-info-bar" );
            info_bar.css( 'opacity', 0 );
            info_bar.css( 'display', 'none' );
            popup.hide();

            let overlay = $( '.preview_wrap .cs_popup_overlay' );
            overlay.css( 'visibility', 'hidden' );
            overlay.css( 'opacity', 0 );
        } );

        jQuery( document ).on( 'click', '.options_btn', function ( e ) {
            e.preventDefault();
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' );
            if ( !popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
            }
            popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
            popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
            jQuery( 'body' ).addClass( "cs-modal-open" );
            popup.find( ".cs-settings-overlay" ).addClass( "cs-show" );
            popup.find( ".cs-info-bar" ).hide();
        } );

        $( '.btn_next_step' ).on( 'click', function () {
            let that = $( this );
            let next = that.closest( '.steps-wrap' ).next();
            that.closest( '.steps-wrap' ).hide();
            next.fadeIn();
        } );

        $( '.btn_second_step' ).on( 'click', function () {
            let that = $( this );
            let next = $( '#cs_step_form' );
            that.closest( '.steps-wrap' ).hide();
            next.fadeIn();
        } );

        $( '.btn_prev_second_step' ).on( 'click', function () {
            let prev = $( '.cs_settings_form' );
            $( '#cs_step_form' ).hide();
            prev.fadeIn();
        } );

        $( '.btn_prev_step' ).on( 'click', function () {
            let that = $( this ),
                prev = that.closest( '.steps-wrap' ).prev();
            that.closest( '.steps-wrap' ).hide();
            prev.fadeIn();
        } );

        $( '.delete_custom_post' ).on( 'click', function ( e ) {
            e.preventDefault();
            let post_id = $( this ).data( 'id' ),
                data_cat = $( this ).data( 'cat' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'post_id=' + post_id + '&data_cat=' + data_cat + '&cs_settings_ajax_update=delete_custom_post&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.delete_cookie_cat_button' ).on( 'click', function () {
            let cat_id = $( this ).data( 'id' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'cs_cookie_cat_id=' + cat_id + '&cs_settings_ajax_update=delete_cookie_cat&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.btn_save_descr' ).on( 'click', function () {
            let submit = $( '#cs_settings_form' ).find( ":submit" );
            submit.trigger( 'click' );
        } );

        $( '.details-control' ).on( 'click', function () {
            $( this ).toggleText( 'Details', 'Close' );
            let tr = $( this ).closest( '.row' ).find( '.details-col' );
            tr.slideToggle();
        } );

        $( '#cs_iab_settings .cs_iab_show_only_vendors' ).on( 'click', function () {
            let tr = $( this ).closest( '.row' ).find( '.cs_iab_show_only_vendors_details' );
            if ( $( this ).is( ':checked' ) ) {
                tr.show();
            } else {
                tr.hide();
            }
        } );

        $( '#cs_iab_settings .cs_iab_show_only_additional_vendors' ).on( 'click', function () {
            let tr = $( this ).closest( '.row' ).find( '.cs_iab_show_only_additional_vendors_details' );
            if ( $( this ).is( ':checked' ) ) {
                tr.show();
            } else {
                tr.hide();
            }
        } );

        let prop = $( '.row-property .cs_consent_for_pys[type=checkbox]' );

        if ( !prop.prop( 'checked' ) ) {
            toggleProperty( prop );
        }

        prop.on( 'click', function () {
            toggleProperty( $( this ) )
        } );

        function toggleProperty( prop ) {
            let tr = prop.closest( '.row-property' ).siblings( '.row-sub-property' ).find( '.row-sub-property-toggle' );
            tr.slideToggle();
        }

        $( '.cs_save_edit_cat' ).on( 'click', function () {
            if ( typeof window.tinyMCE !== 'undefined' ) {
                window.tinyMCE.triggerSave();
            }
            let wrap = $( this ).closest( '.card-body' ).find( '.cs_data_render_wrap_editor' ),
                lang_control = wrap.closest( '.cs_data_render_wrap' ).find( '.cs_input_language_control' ).val(),
                font = '',
                fields = [];

            wrap.each( function () {
                let lang_item = $( this ).find( '.form-control-lang-new' ).attr( 'data-lang' );
                if ( lang_item !== undefined ) {
                    let arr = {
                        'name': $( this ).find( '.cs_cookie_cat_title' ).val(),
                        'descr': $( this ).find( '.cs_cookie_cat_description' ).val(),
                        'lang': lang_item,
                    };
                    fields.push( arr );
                }

                if ( wrap.find( '#cs_default_font' ).val() !== undefined ) {
                    font = '&default_font=' + wrap.find( '#cs_default_font' ).val();
                }
            } );

            let unassigned = 0,
                cat_id = $( this ).data( 'id' ),
                cs_ignore_this_category = 0,
                iab_cat = wrap.find( '.cs_cookie_iab_cat' ).val();

            if ( wrap.find( '.custom-switch-input' ).prop( 'checked' ) == true ) {
                cs_ignore_this_category = 1;
            }
            if ( wrap.find( '#cs_not_block_unassigned_cookies' ).prop( 'checked' ) == true ) {
                unassigned = 1;
            }
            let btn = $( this );
            btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'cs_cookie_cat_fields=' + JSON.stringify( fields ) + '&cs_cookie_cat_id=' + cat_id + '&cs_language_control_' + cat_id + '=' + lang_control + '&cs_settings_ajax_update=update_cookie_cat' + '&cs_ignore_this_category=' + cs_ignore_this_category + '&cs_not_block_unassigned_cookies=' + unassigned + font + '&cs_iab_cat=' + iab_cat + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        $( '.cs_new_cat_description' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap_new_cat' ).show();
        } );

        function isValidIP( str ) {
            const octet4 = '(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]?|0)';
            const regex = new RegExp( `^${octet4}\\.${octet4}\\.${octet4}\\.${octet4}$` );
            if ( regex.test( str ) ) {
                return true
            } else {
                const regex_exp_v6 = '^\\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([ 0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4] \\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]? \\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1, 4}){1,2})|:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[ 0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f] {1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1 ,4})?:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}) {0,2}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}) {0,3}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]| 2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4 }:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}) {0,4}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4] \\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}) {1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\\d|1 \\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)) {3}))|:)))(%.+)?\\s*$';
                const regex6 = new RegExp( `${ regex_exp_v6 }` );
                if ( regex6.test( str ) ) {
                    return true
                }
            }
            return false;
        }

        $( '#add_new_ignore_ip' ).on( 'click', function () {
            let new_ignore_ip = $( '#new_ignore_ip' ).val();

            if ( isValidIP( new_ignore_ip ) ) {
                $( '.cs-error-message' ).fadeOut();
                $.ajax( {
                    url: cmpro_ajax.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'cs_new_ignore_ip',
                        nonce_code: cmpro_ajax.nonce,
                        ignore_ip: new_ignore_ip
                    },
                    success: function ( response ) {
                        console.log( response );
                        if ( response.success ) {
                            $( '.cs-error-message' ).fadeOut();
                            location.reload();
                        } else {
                            $( '.cs-error-message' ).text( 'Duplicate IP address' ).fadeIn();
                        }
                    }
                } );
            } else {
                $( '.cs-error-message' ).text( 'Invalid IP address' ).fadeIn();
            }
        } );

        $( '.cs_renew_consent_cancel_new_cat' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap_new_cat' ).hide();
        } );

        $( '.cs_renew_consent_category_new_cat' ).on( 'click', function () {
            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_renew_consent',
                    nonce_code: cmpro_ajax.nonce
                },
                success: function ( response ) {
                    if ( typeof window.tinyMCE !== 'undefined' ) {
                        window.tinyMCE.triggerSave();
                    }
                    let name = $( '#cs_new_cat_title' ).val(),
                        descr = $( '#cs_new_cat_description' ).val(),
                        iab_cat = $( '.cs_new_cookie_iab_cat' ).val();

                    $.ajax( {
                        url: url,
                        type: 'POST',
                        data: 'cs_cookie_cat_name=' + name + '&cs_cookie_cat_descr=' + descr + '&cs_iab_cat=' + iab_cat + '&cs_settings_ajax_update=add_new_cookie_cat&_wpnonce=' + wpnonce,
                        success: function ( response ) {
                            location.reload();
                        },
                        error: function () {
                            location.reload();
                        }
                    } );
                }
            } );
        } );

        $( 'body' ).on( 'click', '.btn_single_save', function () {
            let submit_btn = $( this );
            submit_btn.removeClass( 'saved-effect' );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            cs_settings_form.submit();
        } );

        $( '.js-control-element' ).on( 'input', function () {
            $( this ).closest( '.card' ).find( '.btn_single_save' ).addClass( 'saved-effect' );
        } );

        $( '.btn_restore_adjust' ).on( 'click', function ( e ) {
            let submit_action = 'btn_restore_adjust',
                submit_btn = $( this );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            e.preventDefault();
            $.ajax( {
                url: url,
                type: 'POST',
                data: {
                    cs_settings_ajax_update: submit_action,
                    _wpnonce: wpnonce,
                },
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    location.reload();
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        $( document ).on( 'click', '.template_delete_btn, .custom_rule_delete_btn', function () {
            let template_id = $( this ).data( 'id' );

            $.ajax( {
                url: url,
                type: 'POST',
                data: 'template_id=' + template_id + '&cs_settings_ajax_update=delete_template&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    location.reload();
                },
                error: function () {
                    console.log( 'error' );
                }
            } );
        } );

        let bars_type = $( '._cs_bars_type' );
        bars_type.on( 'change', function () {
            let check_type = $( '._cs_bars_type' ).children( "option:selected" ).val();
            if ( check_type == 'popup_small' || check_type == 'popup_large' || $( this ).val() == 'popup_small' || $( this ).val() == 'popup_large' ) {
                $( ".cs_bars_position_wrap" ).hide();
            } else {
                $( ".cs_bars_position_wrap" ).show();
            }
        } );
        bars_type.each( function () {
            if ( $( this ).val() == 'bar_small' || $( this ).val() == 'bar_large' ) {
                $( '._cs_bars_position_wrap' ).show();
            } else {
                $( '._cs_bars_position_wrap' ).hide();
            }
        } );

        $( '._cs_custom_text' ).on( 'change', function () {
            if ( $( this ).is( ':checked' ) ) {
                $( '.custom_text_wrap' ).show();
            } else {
                $( '.custom_text_wrap' ).hide();
            }
        } );

        let bars_position = $( '._cs_bars_position' );
        bars_position.each( function () {
            if ( $( this ).val() == 'top' ) {
                $( '.cs_top_push_wrap' ).show();
            } else {
                $( '.cs_top_push_wrap' ).hide();
            }
        } );
        bars_position.on( 'change', function () {
            if ( $( this ).val() == 'top' ) {
                $( '.cs_top_push_wrap' ).show();
                $( '._cs_top_push' ).prop( "checked", true );
            } else {
                $( '.cs_top_push_wrap' ).hide();
                $( '._cs_top_push' ).prop( "checked", false );
            }
        } );

        let check_type = $( '._cs_type' ).children( "option:selected" ).val(),
            design_type = $( '._cs_design_type' );

        function change_options_by_type( check_type ) {
            $( "._cs_bars_position" ).val( "bottom" ).change();
            let sticky = $( '._cs_sticky' ),
                bars_type = $( "._cs_bars_type" ),
                custom_button = $( '.cs_custom_button_block' ),
                close_on_scroll = $( '._cs_close_on_scroll' ),
                refresh_after_consent = $( '._cs_refresh_after_consent' ),
                deny_consent_for_close = $( '._cs_deny_consent_for_close' ),
                smart_sticky = $( '._cs_smart_sticky' ),
                smart_sticky_mobile = $( '._cs_smart_sticky_mobile' ),
                design_type = $( '._cs_design_type' ),
                custom_text = $( '._cs_custom_text' ),
                custom_text_wrap = $( '.cs_custom_text' ),
                native_scripts = $( '._cs_native_scripts' ),
                meta_ldu = $( '._cs_use_meta_ldu' ),
                google_consent_mode = $( '._cs_google_consent_mode' );

            if ( check_type == 'just_inform' ) {
                design_type.val( "multi" ).change();
                design_type.removeClass( 'disabled' );
                bars_type.val( "bar_small" ).change();
                bars_type.removeClass( 'disabled' );
                $( '._cs_privacy_link' ).prop( "checked", true );
                close_on_scroll.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                refresh_after_consent.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_deny_all_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_hide_close_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_block_content' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                smart_sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                smart_sticky_mobile.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                $( ".cs_design_type_wrap" ).hide();
                custom_text_wrap.show();
                native_scripts.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                meta_ldu.prop( "checked", false ).closest( '.list-item' ).hide();
                google_consent_mode.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                google_consent_mode.closest( '.list-item' ).find( '.cs_showing_line' ).hide();

                sticky.prop( {
                    'checked': false,
                    'disabled': false
                } ).closest( '.custom-switch' ).removeClass( 'disabled' ).parent().hide();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', false );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', false );
                } );
            }
            if ( check_type == 'inform_and_opiout' ) {
                design_type.val( "multi" ).change();
                design_type.removeClass( 'disabled' );
                bars_type.val( "bar_small" ).change();
                bars_type.removeClass( 'disabled' );
                $( '._cs_privacy_link' ).prop( "checked", true );
                $( '._cs_block_content' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                $( '._cs_deny_all_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_hide_close_btn' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.closest( '.list-item' ).show();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                refresh_after_consent.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                smart_sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                smart_sticky_mobile.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                $( ".cs_design_type_wrap" ).show();
                custom_text_wrap.show();
                native_scripts.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                meta_ldu.prop( "checked", true ).closest( '.list-item' ).show();
                google_consent_mode.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                google_consent_mode.closest( '.list-item' ).find( '.cs_showing_line' ).hide();

                sticky.prop( {
                    'checked': false,
                    'disabled': false
                } ).closest( '.custom-switch' ).removeClass( 'disabled' ).parent().show();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );
            }
            if ( check_type == 'ask_before_tracking' ) {
                design_type.val( "multi" ).change();
                design_type.removeClass( 'disabled' );
                bars_type.val( "bar_small" ).change();
                bars_type.removeClass( 'disabled' );
                $( '._cs_privacy_link' ).prop( "checked", true );
                $( '._cs_block_content' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).hide();
                $( '._cs_deny_all_btn' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                $( '._cs_hide_close_btn' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                refresh_after_consent.prop( "checked", true ).closest( '.list-item' ).show();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                smart_sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                smart_sticky_mobile.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().show();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( ".cs_design_type_wrap" ).show();
                custom_text_wrap.show();
                native_scripts.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                meta_ldu.prop( "checked", false ).closest( '.list-item' ).show();
                google_consent_mode.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                google_consent_mode.closest( '.list-item' ).find( '.cs_showing_line' ).hide();

                sticky.prop( {
                    'checked': true,
                    'disabled': false
                } ).closest( '.custom-switch' ).removeClass( 'disabled' ).parent().show();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );
            }

            if ( check_type == 'iab' ) {
                design_type.val( "single" ).change();
                design_type.addClass( 'disabled' );
                bars_type.val( "popup_large" ).change();
                bars_type.addClass( 'disabled' );
                $( '._cs_privacy_link' ).prop( "checked", true );
                $( '._cs_block_content' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                close_on_scroll.prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                close_on_scroll.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                $( '._cs_deny_all_btn' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                $( '._cs_hide_close_btn' ).prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                $( '._cs_custom_button' ).prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                $( '._cs_track_analytics' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.prop( "checked", true ).closest( '.list-item' ).show();
                $( '._cs_mobile_side_sticky' ).prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( '._cs_showing_rule_until_express_consent' ).prop( "checked", false ).closest( '.custom-switch' ).parent().hide();
                refresh_after_consent.closest( '.list-item' ).find( '.cs_showing_line' ).show();
                smart_sticky.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                smart_sticky_mobile.prop( "checked", false ).closest( '.custom-switch' ).parent().parent().hide();
                deny_consent_for_close.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                $( ".cs_design_type_wrap" ).show();
                custom_text.prop( 'checked', false );
                custom_text_wrap.hide();
                native_scripts.prop( "checked", true ).closest( '.custom-switch' ).parent().show();
                meta_ldu.prop( "checked", false ).closest( '.list-item' ).hide();
                google_consent_mode.prop( "checked", false ).closest( '.custom-switch' ).parent().show();
                google_consent_mode.closest( '.list-item' ).find( '.cs_showing_line' ).show();

                sticky.prop( {
                    'checked': true,
                    'disabled': true
                } ).closest( '.custom-switch' ).addClass( 'disabled' ).parent().show();
                sticky.closest( '.list-item' ).find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );

                custom_button.find( '.sticky_categories>div:not(.dimmy_checkbox) .small-switch input[type=checkbox]' ).each( function ( index, elem ) {
                    let $elem = $( elem );
                    $elem.prop( 'checked', true );
                } );
            }
        }

        $( '._cs_type' ).on( 'change', function () {
            let check_type = $( '._cs_type' ).children( "option:selected" ).val();
            change_options_by_type( check_type );
        } );

        design_type.on( 'change', function () {
            let bars_type = $( "._cs_bars_type" );
            if ( $( this ).val() == 'single' ) {
                bars_type.val( "popup_large" ).change();
                bars_type.addClass( 'disabled' );
            } else {
                bars_type.val( "bar_small" ).change();
                bars_type.removeClass( 'disabled' );
            }
        } )

        /**
         * Preview functions
         */

        $( '.preview_size_btn' ).on( 'click', function () {
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                prefix = 'cs_d_consent-magic_cs_d_sb_',
                preview_container = $( this ).closest( '.cs_preview_container' );
            popup.html( '' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            switch ( bar_type ) {
                case 'bar_small':
                    prefix = 'cs_d_consent-magic_cs_d_sb_';
                    break;
                case 'bar_large':
                    prefix = 'cs_d_consent-magic_cs_d_lb_';
                    break;
                case 'popup_small':
                    prefix = 'cs_d_consent-magic_cs_d_sp_';
                    break;
                case 'popup_large':
                    prefix = 'cs_d_consent-magic_cs_d_lp_';
                    break;
            }

            let wrap_type = $( 'body' ).find( '.cs_wrap_type.' + bar_type ),
                option_wrap = $( 'body' ).find( '.cs_wrap_type.options_popup' ),
                min_height = $( 'input[id^="' + prefix + 'min_height"]' ).val(),
                pd_top = $( 'input[id^="' + prefix + 'padding_top"]' ).val(),
                pd_bottom = $( 'input[id^="' + prefix + 'padding_bottom"]' ).val(),
                pd_left = $( 'input[id^="' + prefix + 'padding_left"]' ).val(),
                pd_right = $( 'input[id^="' + prefix + 'padding_right"]' ).val(),
                font_s = $( 'input[id^="' + prefix + 'font_size"]' ).val(),
                font_w = $( '#' + prefix + 'font_weight' ).children( "option:selected" ).val(),
                btn_pd_t = $( 'input[id^="' + prefix + 'btn_pd_t"]' ).val(),
                btn_pd_b = $( 'input[id^="' + prefix + 'btn_pd_bt"]' ).val(),
                btn_pd_l = $( 'input[id^="' + prefix + 'btn_pd_l"]' ).val(),
                btn_pd_r = $( 'input[id^="' + prefix + 'btn_pd_r"]' ).val(),
                btn_mg_t = $( 'input[id^="' + prefix + 'btn_mg_t"]' ).val(),
                btn_mg_b = $( 'input[id^="' + prefix + 'btn_mg_bt"]' ).val(),
                btn_mg_l = $( 'input[id^="' + prefix + 'btn_mg_l"]' ).val(),
                btn_mg_r = $( 'input[id^="' + prefix + 'btn_mg_r"]' ).val(),
                btn_font_s = $( 'input[id^="' + prefix + 'btn_font_size"]' ).val(),
                btn_font_w = $( '#' + prefix + 'btn_font_weight' ).children( "option:selected" ).val(),
                op_min_height = $( 'input[id^="cs_d_consent-magic_cs_d_op_min_height"]' ).val(),
                op_pd_top = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_top"]' ).val(),
                op_pd_bottom = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_bottom"]' ).val(),
                op_pd_left = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_left"]' ).val(),
                op_pd_right = $( 'input[id^="cs_d_consent-magic_cs_d_op_padding_right"]' ).val(),
                op_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_font_size"]' ).val(),
                op_font_w = $( '#cs_d_consent-magic_cs_d_op_font_weight' ).children( "option:selected" ).val(),
                op_btn_pd_t = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_t"]' ).val(),
                op_btn_pd_b = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_bt"]' ).val(),
                op_btn_pd_l = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_l"]' ).val(),
                op_btn_pd_r = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_pd_r"]' ).val(),
                op_btn_mg_t = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_t"]' ).val(),
                op_btn_mg_b = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_bt"]' ).val(),
                op_btn_mg_l = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_l"]' ).val(),
                op_btn_mg_r = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_mg_r"]' ).val(),
                op_btn_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_btn_font_size"]' ).val(),
                op_title_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_titles_font_size"]' ).val(),
                op_subtitle_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_op_subtitles_font_size"]' ).val(),
                op_btn_font_w = $( '#cs_d_consent-magic_cs_d_op_btn_font_weight' ).children( "option:selected" ).val(),
                op_title_f_w = $( '#cs_d_consent-magic_cs_d_op_titles_font_weight' ).children( "option:selected" ).val(),
                op_subtitle_f_w = $( '#cs_d_consent-magic_cs_d_op_subtitles_font_weight' ).children( "option:selected" ).val();

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_size_show',
                    bar_type: bar_type,
                    min_height: min_height,
                    pd_top: pd_top,
                    pd_bottom: pd_bottom,
                    pd_left: pd_left,
                    pd_right: pd_right,
                    font_s: font_s,
                    font_w: font_w,
                    btn_pd_t: btn_pd_t,
                    btn_pd_b: btn_pd_b,
                    btn_pd_l: btn_pd_l,
                    btn_pd_r: btn_pd_r,
                    btn_mg_t: btn_mg_t,
                    btn_mg_b: btn_mg_b,
                    btn_mg_r: btn_mg_r,
                    btn_mg_l: btn_mg_l,
                    btn_font_s: btn_font_s,
                    btn_font_w: btn_font_w,
                    op_min_height: op_min_height,
                    op_pd_top: op_pd_top,
                    op_pd_bottom: op_pd_bottom,
                    op_pd_left: op_pd_left,
                    op_pd_right: op_pd_right,
                    op_font_s: op_font_s,
                    op_font_w: op_font_w,
                    op_btn_pd_t: op_btn_pd_t,
                    op_btn_pd_b: op_btn_pd_b,
                    op_btn_pd_l: op_btn_pd_l,
                    op_btn_pd_r: op_btn_pd_r,
                    op_btn_mg_t: op_btn_mg_t,
                    op_btn_mg_b: op_btn_mg_b,
                    op_btn_mg_l: op_btn_mg_l,
                    op_btn_mg_r: op_btn_mg_r,
                    op_btn_font_s: op_btn_font_s,
                    op_title_f_s: op_title_f_s,
                    op_subtitle_f_s: op_subtitle_f_s,
                    op_btn_font_w: op_btn_font_w,
                    op_title_f_w: op_title_f_w,
                    op_subtitle_f_w: op_subtitle_f_w,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response.data.html );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        /**
         * Preview functions for single step design
         */
        $( '.preview_size_single_btn' ).on( 'click', function () {
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' );

            $( this ).closest( '.cs_preview_container' ).addClass( 'popup_large' )
            popup.html( '' );

            let op_pd_t = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_padding_top"]' ).val(),
                op_pd_b = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_padding_bottom"]' ).val(),
                op_pd_l = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_padding_left"]' ).val(),
                op_pd_r = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_padding_right"]' ).val(),
                op_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_font_size"]' ).val(),
                op_font_w = $( '#cs_d_consent-magic_cs_d_single_op_font_weight' ).children( "option:selected" ).val(),
                op_second_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_second_font_size"]' ).val(),
                op_second_font_w = $( '#cs_d_consent-magic_cs_d_single_op_second_font_weight' ).children( "option:selected" ).val(),
                op_title_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_titles_font_size"]' ).val(),
                op_title_f_w = $( '#cs_d_consent-magic_cs_d_single_op_titles_font_weight' ).children( "option:selected" ).val(),
                op_subtitle_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_subtitles_font_size"]' ).val(),
                op_subtitle_f_w = $( '#cs_d_consent-magic_cs_d_single_op_subtitles_font_weight' ).children( "option:selected" ).val(),
                op_subsubtitle_f_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_subsubtitles_font_size"]' ).val(),
                op_subsubtitle_f_w = $( '#cs_d_consent-magic_cs_d_single_op_subsubtitles_font_weight' ).children( "option:selected" ).val(),
                op_btn_pd_t = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_pd_t"]' ).val(),
                op_btn_pd_b = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_pd_b"]' ).val(),
                op_btn_pd_l = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_pd_l"]' ).val(),
                op_btn_pd_r = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_pd_r"]' ).val(),
                op_btn_mg_t = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_mg_t"]' ).val(),
                op_btn_mg_b = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_mg_b"]' ).val(),
                op_btn_mg_l = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_mg_l"]' ).val(),
                op_btn_mg_r = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_mg_r"]' ).val(),
                op_btn_font_s = $( 'input[id^="cs_d_consent-magic_cs_d_single_op_btn_font_size"]' ).val(),
                op_btn_font_w = $( '#cs_d_consent-magic_cs_d_single_op_btn_font_weight' ).children( "option:selected" ).val();

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_size_single_show',
                    op_pd_t: op_pd_t,
                    op_pd_b: op_pd_b,
                    op_pd_l: op_pd_l,
                    op_pd_r: op_pd_r,
                    op_font_s: op_font_s,
                    op_font_w: op_font_w,
                    op_second_font_s: op_second_font_s,
                    op_second_font_w: op_second_font_w,
                    op_btn_pd_t: op_btn_pd_t,
                    op_btn_pd_b: op_btn_pd_b,
                    op_btn_pd_l: op_btn_pd_l,
                    op_btn_pd_r: op_btn_pd_r,
                    op_btn_mg_t: op_btn_mg_t,
                    op_btn_mg_b: op_btn_mg_b,
                    op_btn_mg_l: op_btn_mg_l,
                    op_btn_mg_r: op_btn_mg_r,
                    op_btn_font_s: op_btn_font_s,
                    op_btn_font_w: op_btn_font_w,
                    op_title_f_s: op_title_f_s,
                    op_title_f_w: op_title_f_w,
                    op_subtitle_f_s: op_subtitle_f_s,
                    op_subtitle_f_w: op_subtitle_f_w,
                    op_subsubtitle_f_s: op_subsubtitle_f_s,
                    op_subsubtitle_f_w: op_subsubtitle_f_w,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response.data.html );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
                    popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.preview_color_btn' ).on( 'click', function () {
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                cs_border_style = $( '#cs_cs_border_style' ).children( "option:selected" ).val(),
                cs_backend_color = $( '#cs_cs_backend_color' ).val(),
                cs_border_weight = $( 'input[id^="cs_consent-magic_cs_border_weight"]' ).val(),
                cs_border_color = $( '#cs_cs_border_color' ).val(),
                cs_text_block_bg = $( '#cs_cs_text_block_bg' ).val(),
                cs_text_color = $( '#cs_cs_text_color' ).val(),
                cs_links_color = $( '#cs_cs_links_color' ).val(),
                cs_titles_text_color = $( '#cs_cs_titles_text_color' ).val(),
                cs_subtitles_text_color = $( '#cs_cs_subtitles_text_color' ).val(),
                cs_accept_all_buttons_bg = $( '#cs_cs_accept_all_buttons_bg' ).val(),
                cs_accept_all_buttons_text_color = $( '#cs_cs_accept_all_buttons_text_color' ).val(),
                cs_custom_button_buttons_bg = $( '#cs_cs_custom_button_buttons_bg' ).val(),
                cs_custom_button_buttons_text_color = $( '#cs_cs_custom_button_buttons_text_color' ).val(),
                cs_deny_all_buttons_bg = $( '#cs_cs_deny_all_buttons_bg' ).val(),
                cs_deny_all_buttons_text_color = $( '#cs_cs_deny_all_buttons_text_color' ).val(),
                cs_options_buttons_text_color = $( '#cs_cs_options_buttons_text_color' ).val(),
                cs_options_buttons_bg = $( '#cs_cs_options_buttons_bg' ).val(),
                cs_confirm_buttons_bg = $( '#cs_cs_confirm_buttons_bg' ).val(),
                cs_confirm_buttons_text_color = $( '#cs_cs_confirm_buttons_text_color' ).val(),
                cs_sticky_bg = $( '#cs_cs_sticky_bg' ).val(),
                cs_sticky_link_color = $( '#cs_cs_sticky_link_color' ).val(),
                cs_logo_size = $( '#cs_cs_logo_size' ).children( "option:selected" ).val(),
                cs_logo = $( '#cs_cs_logo' ).val(),
                cs_position_vertical_list = $( '#cs_cs_position_vertical_list' ).children( "option:selected" ).val(),
                cs_position_horizontal_list = $( '#cs_cs_position_horizontal_list' ).children( "option:selected" ).val(),
                cs_cat_color = $( '#cs_cs_cat_color' ).val(),
                cs_active_toggle_text_color = $( '#cs_active_toggle_text_color' ).val(),
                cs_active_toggle_color = $( '#cs_cs_active_toggle_color' ).val(),
                preview_container = $( this ).closest( '.cs_preview_container' ),
                cs_shortcodes_text_color = $( '#cs_cs_shortcodes_text_color' ).val();
            popup.html( '' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            if ( cs_border_style == null ) {
                cs_border_style = $( '#cs_d_consent-magic_cs_border_style' ).children( "option:selected" ).val();
            }

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_color_show',
                    cs_backend_color: cs_backend_color,
                    cs_border_style: cs_border_style,
                    cs_border_weight: cs_border_weight,
                    cs_border_color: cs_border_color,
                    cs_text_block_bg: cs_text_block_bg,
                    cs_text_color: cs_text_color,
                    cs_links_color: cs_links_color,
                    cs_titles_text_color: cs_titles_text_color,
                    cs_subtitles_text_color: cs_subtitles_text_color,
                    cs_accept_all_buttons_bg: cs_accept_all_buttons_bg,
                    cs_accept_all_buttons_text_color: cs_accept_all_buttons_text_color,
                    cs_custom_button_buttons_bg: cs_custom_button_buttons_bg,
                    cs_custom_button_buttons_text_color: cs_custom_button_buttons_text_color,
                    cs_deny_all_buttons_bg: cs_deny_all_buttons_bg,
                    cs_deny_all_buttons_text_color: cs_deny_all_buttons_text_color,
                    cs_options_buttons_text_color: cs_options_buttons_text_color,
                    cs_options_buttons_bg: cs_options_buttons_bg,
                    cs_confirm_buttons_bg: cs_confirm_buttons_bg,
                    cs_confirm_buttons_text_color: cs_confirm_buttons_text_color,
                    cs_sticky_bg: cs_sticky_bg,
                    cs_sticky_link_color: cs_sticky_link_color,
                    cs_logo: cs_logo,
                    cs_position_vertical_list: cs_position_vertical_list,
                    cs_position_horizontal_list: cs_position_horizontal_list,
                    cs_logo_size: cs_logo_size,
                    cs_cat_color: cs_cat_color,
                    cs_active_toggle_color: cs_active_toggle_color,
                    cs_active_toggle_text_color: cs_active_toggle_text_color,
                    bar_type: bar_type,
                    cs_shortcodes_text_color: cs_shortcodes_text_color,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                        popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    }
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    if ( popup.find( '.cs-modal' )?.hasClass( 'cs_single_design' ) ) {
                        popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
                        popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
                    }
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.btn_preview_rule_edit' ).on( 'click', function () {
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                consent_type = $( '._cs_type' ).children( "option:selected" ).val(),
                privacy = 0,
                bar_theme = $( '._cs_theme' ).children( "option:selected" ).val(),
                bar_type = $( '._cs_bars_type' ).children( "option:selected" ).val(),
                bar_position = $( '._cs_bars_position' ).children( "option:selected" ).val(),
                cs_design_type = $( '._cs_design_type' ).children( "option:selected" ).val(),
                deny_all_btn = 0,
                hide_close_btn = 0,
                custom_button = 0,
                sticky = 0,
                cs_rule_id = $( '#cs_rule_id' ).val(),
                preview_container = $( this ).closest( '.cs_preview_container' ),
                cs_iab = 0;
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );
            if ( $( '._cs_privacy_link' ).is( ':checked' ) ) {
                privacy = 1;
            }
            if ( $( '._cs_deny_all_btn' ).is( ':checked' ) ) {
                deny_all_btn = 1;
            }
            if ( $( '._cs_sticky' ).is( ':checked' ) ) {
                sticky = 1;
            }
            if ( $( '._cs_custom_button' ).is( ':checked' ) ) {
                custom_button = 1;
            }
            if ( $( '._cs_hide_close_btn' ).is( ':checked' ) ) {
                hide_close_btn = 1;
            }
            popup.html( '' );
            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_preview_show',
                    cs_type: consent_type,
                    cs_privacy: privacy,
                    cs_sticky: sticky,
                    cs_theme: bar_theme,
                    cs_bar_type: bar_type,
                    cs_bar_position: bar_position,
                    cs_design_type: cs_design_type,
                    cs_deny_all_btn: deny_all_btn,
                    cs_custom_button: custom_button,
                    cs_hide_close_btn: hide_close_btn,
                    cs_rule_id: cs_rule_id,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                    }
                    popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();
                    if ( popup.find( '.cs-modal' )?.hasClass( 'cs_single_design' ) ) {
                        popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
                        popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
                    }
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.btn_preview_rule' ).on( 'click', function () {
            $( '.preview_wrap' ).show();
            if ( $( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
                jQuery( ".cs-popupbar-overlay" ).addClass( "cs-show" );
            }
            jQuery( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
        } );

        $( '.preview_action_btn' ).on( 'click', function () {

            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                preview_container = $( this ).closest( '.cs_preview_container' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                jQuery( 'body' ).addClass( "cs-barmodal-open" );
                popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
            }
            popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
            popup.show();

            if ( popup.find( '.cs-modal' )?.hasClass( 'cs_single_design' ) ) {
                popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
                popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
            }
            cs_show_popup_overlay();
        } );

        $( '.preview_list_action_btn' ).on( 'click', function () {
            let popup = $( this ).closest( '.preview_container' ).find( '.preview_wrap' ),
                bar_type = $( this ).data( 'template' ),
                preview_container = $( this ).closest( '.cs_preview_container' ),
                id = $( this ).data( 'id' );
            preview_container.removeClass( 'bar_small bar_large popup_small popup_large' ).addClass( bar_type );

            popup.html( '' );
            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'preview_list_show',
                    cs_rule_id: id,
                    _wpnonce: wpnonce
                },
                success: function ( response ) {
                    popup.html( response );
                    if ( popup.find( '.cs-info-bar' ).hasClass( 'cs-public-cookie-popup' ) ) {
                        jQuery( 'body' ).addClass( "cs-barmodal-open" );
                    }
                    popup.find( ".cs-popupbar-overlay" ).addClass( "cs-show" );
                    popup.find( ".cs-info-bar" ).css( { 'opacity': 1, 'display': 'block' } );
                    popup.show();

                    if ( popup.find( '.cs-modal' )?.hasClass( 'cs_single_design' ) ) {
                        popup.find( '.cs_settings_popup' ).addClass( "cs-show" ).css( { 'opacity': 0 } ).animate( { 'opacity': 1 } );
                        popup.find( '.cs_settings_popup' ).removeClass( 'cs-blowup cs-out' ).addClass( "cs-blowup" );
                    }
                    cs_show_popup_overlay();
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.cs_sub_tab__script_block li' ).on( "click", function () {
            let trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).parent( '.cs_sub_tab' ),
                ctnr = prnt.siblings( '.cs_sub_tab_container' );
            localStorage.setItem( 'activeSubTabScriptBlock', trgt );
            prnt.find( 'li' ).removeClass( 'active' );
            $( this ).addClass( 'active' );
            ctnr.find( '.cs_sub_tab_content' ).hide();
            ctnr.find( '.cs_sub_tab_content[data-id="' + trgt + '"]' ).fadeIn();
        } );

        $( '.open_target_tab' ).on( "click", function ( e ) {
            let trgt = $( this ).attr( 'data-target' );
            e.preventDefault();
            $( '.cs_sub_tab ' ).find( "[data-target='" + trgt + "']" ).trigger( 'click' );
            $( 'html, body' ).animate( { scrollTop: 0 }, 1500 );
        } );

        $( '.cs_sub_tab__script_block' ).each( function () {
            let activeSubTabScriptBlock = localStorage.getItem( 'activeSubTabScriptBlock' ),
                elm_tp = $( this ).find( "[data-target='" + activeSubTabScriptBlock + "']" );
            if ( activeSubTabScriptBlock == null ) {
                activeSubTabScriptBlock = $( this ).find( "li:eq(0)" ).attr( 'data-target' );
                elm_tp = $( this ).find( "[data-target='" + activeSubTabScriptBlock + "']" );
            }
            elm_tp.trigger( "click" );
        } );

        $( '.templates_sub_tab li' ).on( "click", function () {
            let trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).parent( '.cs_sub_tab' ),
                ctnr = prnt.siblings( '.cs_sub_tab_container' );
            localStorage.setItem( 'activeSubTabTemplate', trgt );
            prnt.find( 'li' ).removeClass( 'active' );
            $( this ).addClass( 'active' );
            ctnr.find( '.cs_sub_tab_content' ).hide();
            ctnr.find( '.cs_sub_tab_content[data-id="' + trgt + '"]' ).fadeIn();
        } );

        $( '.templates_sub_tab' ).each( function () {
            let activeSubTabTemplate = localStorage.getItem( 'activeSubTabTemplate' ),
                elm_tp = $( this ).find( "[data-target='" + activeSubTabTemplate + "']" );
            if ( activeSubTabTemplate == null ) {
                activeSubTabTemplate = $( this ).find( "li:eq(0)" ).attr( 'data-target' );
                elm_tp = $( this ).find( "[data-target='" + activeSubTabTemplate + "']" );
            }
            elm_tp.trigger( "click" );
        } );

        $( '.cs_force_update' ).on( 'click', function ( e ) {
            let submit_btn = $( this );
            submit_btn.hide();
            $( '.fancy-spinner' ).css( { 'opacity': '1', 'height': '3rem' } );
            let message_wrap = $( this ).siblings( '.cs_message_db_update' );
            message_wrap.hide();

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_force_update',
                    nonce_code: cmpro_ajax.nonce
                },
                success: function ( data ) {

                    submit_btn.show();
                    $( '.fancy-spinner' ).css( { 'opacity': '0', 'height': '0' } );
                    message_wrap.html( data.data.message );
                    message_wrap.show();

                },
                error: function ( data ) {
                    console.log( data )
                }
            } );
        } );

        /**
         * Forms submitted functions
         */

        cs_settings_form.on( 'submit', function ( e ) {
            if ( window.tinyMCE ) {
                window.tinyMCE.triggerSave();
            }

            let submit_action = $( '#cs_update_action' ).val(),
                btn_single_save = $( '.btn_single_save' ),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                cs_target = $( '#cs_countries_target' ).val(),
                submit_btn = $( this ).find( 'input[type="submit"]' ),
                cs_target_result = [];

            if ( cs_target ) {
                cs_target_result = cs_target.split( ',' );
            }
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_cs_target=' + cs_target_result + '&_wpnonce=' + wpnonce,
                success: function ( response ) {
                    if ( response ) {
                        if ( check_type != $( '._cs_type' ).children( "option:selected" ).val() ) {
                            $.ajax( {
                                url: cmpro_ajax.ajaxurl,
                                type: 'POST',
                                data: {
                                    action: 'cs_renew_consent',
                                    nonce_code: cmpro_ajax.nonce
                                },
                                success: function ( response ) {
                                    if ( response.success ) {
                                        location.reload();
                                    } else {
                                        console.log( response );
                                    }
                                }
                            } );
                        }
                        submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        if ( submit_btn.closest( '.container' ).hasClass( 'edit_rule_container' ) ) {
                            window.location.href = url;
                        } else {
                            location.reload();
                        }
                    } else {
                        submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                        btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    }
                }
            } );
        } );

        cs_step_form.on( 'submit', function ( e ) {
            let submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                step_url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            $( '.fancy-spinner' ).css( { 'opacity': '1', 'height': '3rem' } );
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: step_url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    window.location = step_url;
                }
            } );
        } );

        cs_design_form.on( 'submit', function ( e ) {
            let submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    let page_url = new URL( document.URL ),
                        design = page_url.searchParams.get( "design" );

                    window.location.href = url + '&tab=' + design;
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_script_form.on( 'submit', function ( e ) {
            if ( typeof window.tinyMCE !== 'undefined' ) {
                window.tinyMCE.triggerSave();
            }
            let submit_action = $( '#cs_update_action' ).val(),
                heedle = $( '#cs_cs_default_script_js_heedle' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&heedle=' + heedle + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url + '&tab=cs-script-blocking';
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_cookie_form.on( 'submit', function ( e ) {
            if ( typeof window.tinyMCE !== 'undefined' ) {
                window.tinyMCE.triggerSave();
            }
            let submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url + '&tab=cs-script-blocking';
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_new_rule_form.on( 'submit', function ( e ) {
            if ( typeof window.tinyMCE !== 'undefined' ) {
                window.tinyMCE.triggerSave();
            }
            let submit_action = $( '#cs_update_action' ).val(),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' ),
                cs_target = $( '#_cs_target' ).cs_select2( "data" ),
                cs_target_result = [];

            for ( let i = 0; i <= cs_target.length - 1; i++ ) {
                cs_target_result.push( cs_target[ i ].id );
            }
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&_cs_target=' + cs_target_result + '&_wpnonce=' + wpnonce,
                success: function ( data ) {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location.href = url;
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        cs_settings_tab_form.on( 'submit', function ( e ) {
            let permissions = $( '#cs_cs_admin_permissions' ).val(),
                ignore_users = $( '#cs_cs_admin_ignore_users' ).val(),
                ignore_users_ip = $( '#cs_cs_admin_ignore_users_ip' ).val(),
                important_emails = $( '#cs_cs_send_important_emails' ).val(),
                submit_action = $( '#cs_update_action' ).val(),
                btn_single_save = $( '.btn_single_save' ),
                data = $( this ).serialize(),
                url = $( this ).attr( 'action' ),
                submit_btn = $( this ).find( 'input[type="submit"]' );
            e.preventDefault();
            submit_btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: url,
                type: 'POST',
                data: data + '&cs_settings_ajax_update=' + submit_action + '&permissions=' + permissions + '&important_emails=' + important_emails + '&ignore_users=' + ignore_users + '&ignore_users_ip=' + ignore_users_ip + '&_wpnonce=' + wpnonce,
                success: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    location.reload();
                },
                error: function () {
                    submit_btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    btn_single_save.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                }
            } );
        } );

        $( '.cs_renew_consent_cancel' ).on( 'click', function () {
            let element = $( '.cs_renew_consent_wrap' ).attr( 'data-id' );
            if ( $( '#' + element ).prop( 'checked' ) == false ) {
                $( '#' + element ).prop( 'checked', true );
            } else {
                $( '#' + element ).prop( 'checked', false );
            }
            $( '.cs_renew_consent_wrap' ).hide();
        } );

        $( '.cs_renew_consent_category' ).on( 'click', function () {
            let element = $( '.cs_renew_consent_wrap' ).attr( 'data-id' );
            $( '#' + element ).closest( '.card-body' ).find( '.cs_save_edit_cat' ).trigger( 'click' );
        } );

        /**
         * Settings actions
         */

        $( '.cs_renew_consent_confirm' ).on( 'click', function () {
            $( '.cs_renew_consent_wrap' ).show();
        } );

        $( '.cs_restart_setup' ).on( 'click', function () {
            $( '.cs_restart_setup_wrap' ).show();
        } );

        $( '.cs_deactivation_db_clear' ).on( 'change', function () {
            if ( $( '.cs_deactivation_db_clear' ).is( ':checked' ) ) {
                $( '.cs_deactivation_db_clear_popup' ).show();
            }
        } );

        $( '.cs_deactivation_db_clear_close' ).on( 'click', function () {
            $( '.cs_deactivation_db_clear_popup' ).hide();
            $( '.cs_deactivation_db_clear' ).prop( 'checked', false );
        } );

        $( '.delete_proof_consent' ).on( 'click', function () {
            $( '.cs_delete_proof_consent_wrap' ).show();
        } );

        $( '.delete_proof_consent_close' ).on( 'click', function () {
            $( '.cs_delete_proof_consent_wrap' ).hide();
        } );

        $( '.restore_translations' ).on( 'click', function () {
            $( '.cs_restore_translations_wrap' ).show();
        } );

        $( '.restore_translations_close' ).on( 'click', function () {
            $( '.cs_restore_translations_wrap' ).hide();
        } );

        $( '.cs_restart_setup_close' ).on( 'click', function () {
            $( '.cs_restart_setup_wrap' ).hide();
        } );

        $( '.cs_renew_consent' ).on( 'click', function () {
            let button = $( this );
            button.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $( '.cs_renew_consent_wrap' ).hide();
            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_renew_consent',
                    nonce_code: cmpro_ajax.nonce
                },
                success: function ( response ) {
                    button.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        $( '.cs_delete_license' ).on( 'click', function () {
            let button = $( this );
            button.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );
            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_instance_update',
                    nonce_code: cmpro_ajax.nonce_code,
                },
                success: function ( response ) {
                    button.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                    window.location = '/wp-admin/admin.php?page=cs-license';
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
        } );

        /**
         * multi select functions
         */

        $( '.cs_multi_select' ).cs_select2();

        $( ".cs_multi_select_tags" ).cs_select2( { tags: true } );

        /**
         * Images uploaded functions
         */

        $( document ).on( 'click', '.cs_img_upload', function ( e ) {
            e.preventDefault();
            let custom_uploader = wp.media( {
                title: 'Insert image',
                library: {
                    type: 'image'
                },
                button: {
                    text: 'Use this image'
                },
                multiple: false
            } ).on( 'select', function () {
                let attachment = custom_uploader.state().get( 'selection' ).first().toJSON();
                $( '.cs_logo_img_wrap' ).append( '<img src="' + attachment.sizes.full.url + '" alt="">' );
                $( '.img_recommender' ).css( 'display', 'block' );
                $( '.cs_img_upload_rmv' ).css( 'display', 'block' );
                $( '#cs_cs_logo' ).val( attachment.id );
            } ).open();
        } );

        $( document ).on( 'click', '.cs_img_upload_rmv', function ( e ) {
            e.preventDefault();
            $( '.cs_logo_img_wrap' ).find( 'img' ).remove();
            $( '#cs_cs_logo' ).val( '' );
            $( this ).css( 'display', 'none' );
            $( '.img_recommender' ).css( 'display', 'none' );
        } );

        //change language text
        $( '.form-control-lang' ).cs_select2( {
            closeOnSelect: true,
            allowClear: false,
        } ).on( 'cs_select2:select', function ( e ) {

            let id = $( this ).closest( '.cs_data_render_wrap' ).find( '.js-control-element' ).attr( 'id' );
            cs_select2_processing( e, $( this ), id );

        } );

        //add form for new language
        $( '.add_new_lang_action' ).on( 'click', function () {
            let add_html = $( this ).siblings( '.add_new_lang' ),

                key = $( this ).attr( 'data-key' ),
                render = $( this ).attr( 'data-render' ),
                id = key + '_' + ( new Date() ).getTime(),
                language_list = $( this ).closest( '.sub-card-body' ).find( '.language_list' );

            language_list.find( '.cs_empty_langs' ).remove();
            language_list.append( add_html.html() );
            language_list.find( '.cs_data_render_wrap:not([class*="cs_data_render_wrap_editor"])' ).addClass( "cs_data_render_wrap_editor" );

            let add_new_lang = language_list.parent().find( '.language_list > .cart_line_item:last-child' );
            add_new_lang.find( '.cs_select2-container' ).remove();
            add_new_lang.find( '.form-control-lang-add' ).addClass( 'form-control-lang-new' );
            let meta = add_new_lang.find( '.form-control-lang-new' ).cs_select2( {
                closeOnSelect: true,
                allowClear: false,
            } ).on( 'cs_select2:select', function ( e ) {
                cs_select2_processing( e, $( this ), id );
            } ).attr( 'data-option-type' );

            let name = '';
            if ( meta == 1 ) {
                name = key + '_0';
            } else {
                name = 'cs[' + $( this ).attr( 'data-plugin-name' ) + '][' + key + '_0]';
            }

            if ( render == 'renderWpEditor' || render == 'renderWpEditorByTerm' ) {
                let textarea;
                if ( render == 'renderWpEditorByTerm' ) {
                    textarea = '<textarea id="' + id + '" name="' + name + '" class="cs_cookie_cat_description"></textarea>';
                } else {
                    textarea = '<textarea id="' + id + '" name="' + name + '"></textarea>';
                }

                add_new_lang.find( '.cs_data_render' ).append( textarea );
                init_wp_editor( id );

                let class_list = $( this ).closest( '.card-body' ).find( '.input_row_default .cs_data_render_wrap textarea' ).attr( "class" );
                if ( class_list !== undefined ) {
                    class_list.split( /\s+/ );
                    $( '#' + id ).addClass( class_list );
                }

            } else if ( render == 'renderTextInput' ) {
                let input = '<input type="text" id="' + id + '" name="' + name + '">',
                    class_list = $( this ).closest( '.cart_line_item' ).find( '.input_row_default .cs_data_render_wrap input' ).attr( "class" ).split( /\s+/ );

                $( '#' + id ).addClass( class_list );
                add_new_lang.find( '.cs_data_render' ).append( input );
            }
        } );

        function cs_select2_processing( e, $this, id ) {
            let data = e.params.data,
                plugin_name = $this.attr( 'data-plugin-name' ),
                key = $this.attr( 'data-field' );

            $this.attr( 'data-lang', data.id );
            let meta = $this.attr( 'data-option-type' );
            if ( meta == 1 ) {
                $( '#' + id ).attr( 'name', key + '_' + data.id );
            } else {
                $( '#' + id ).attr( 'name', 'cs[' + plugin_name + '][' + key + '_' + data.id + ']' );
            }
        }

        $( document ).on( 'click', '.cs-delete-lang', function () {

            let wrap = $( this ).closest( '.cart_line_item' ),
                lang_select = wrap.find( 'select[class^="form-control-lang"]' ),
                lang = lang_select.attr( 'data-lang' ),
                meta = lang_select.attr( 'data-option-type' ),
                key = lang_select.attr( 'data-field' ),
                id = lang_select.attr( 'data-rule' ),
                term = $( this ).hasClass( 'cs-delete-lang-term' ) ? 1 : 0;
            $( this ).closest( '.cart_line_item' ).remove();

            if ( lang != undefined ) {
                $.ajax( {
                    url: cmpro_ajax.ajaxurl,
                    type: 'POST',
                    data: {
                        action: 'cs_delete_lang',
                        lang: lang,
                        meta: meta,
                        key: key,
                        id: ( id != '' ) ? id : false,
                        term: term,
                        _wpnonce: wpnonce,
                    },
                    error: function ( response ) {
                        console.log( response );
                    }
                } );
            }
        } )

        //toggle geolocation settings
        $( '.cs_geolocation' ).on( 'click', function () {
            $( this ).closest( '#geolocation-settings-wrap' ).toggleClass( 'geo_disable' );
        } );

        // activate/deactivate geo license
        $( '.cs_activate_geo_license' ).on( 'click', function () {

            let key = $( '#cs_cs_geo_licence_key' ).val(),
                account_id = $( '#cs_cs_geo_licence_account_id' ).val(),
                message = $( '.cs_geo_license_message' ),
                btn = $( this ),
                text_activate = btn.attr( 'data-activate' ),
                text_deactivate = btn.attr( 'data-deactivate' ),
                license_action = btn.attr( 'data-action' );

            btn.css( { 'opacity': '.5', 'cursor': 'default' } ).prop( 'disabled', true );

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    'key': key,
                    'account_id': account_id,
                    'license_action': license_action,
                    'action': 'cs_check_geo_license',
                    _wpnonce: wpnonce,
                },
                success: function ( data ) {
                    if ( data.data.status == true && data.data.license_action == 1 ) {

                        message.addClass( 'cs_geo_license_message_activated' );
                        btn.html( text_deactivate );
                        btn.attr( 'data-action', 0 );

                    } else {
                        message.removeClass( 'cs_geo_license_message_activated' );
                        btn.html( text_activate );
                        btn.attr( 'data-action', 1 );
                    }
                    message.html( data.data.message );
                    btn.css( { 'opacity': '1', 'cursor': 'pointer' } ).prop( 'disabled', false );
                },
                error: function ( data ) {
                    console.log( 'error' );
                }
            } );
        } );

        //load additional languages for text fields
        $( '.cs_load_langs' ).on( 'click', function ( click_event ) {
            $( this ).removeClass( 'cs_load_langs' );
            let render = $( this ).attr( 'data-render' ),
                language_block = $( this ).closest( '.sub-card' ),
                add_html = language_block.find( '.sub-card-body .add_new_lang' ),
                data_add = language_block.find( '.add_new_lang_action' ),
                key = $( this ).attr( 'data-key' ),
                language_list = language_block.find( '.sub-card-body .language_list' ),
                term = $( this ).attr( 'data-option-type' );

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                type: 'POST',
                data: {
                    action: 'cs_load_langs',
                    current_lang: $( this ).attr( 'data-current-lang' ),
                    key: key,
                    term: term,
                    nonce_code: cmpro_ajax.nonce,
                },
                success: async function ( data ) {
                    let lang_list = data.data.lang_list;

                    if ( typeof lang_list === "object" && Object.keys( lang_list ).length > 0 ) {
                        for ( let k in lang_list ) {

                            add_html.find( '.cs_data_render_wrap:not([class*="cs_data_render_wrap_editor"])' ).addClass( "cs_data_render_wrap_editor" );
                            language_list.append( add_html.html() );
                            let add_new_lang = language_list.parent().find( '.language_list > .cart_line_item:last-child' );
                            add_new_lang.find( '.cs_select2-container' ).remove();
                            add_new_lang.find( '.form-control-lang-add' ).addClass( 'form-control-lang-new' );

                            if ( lang_list[ k ][ 'enable' ] == 0 ) {
                                add_new_lang.css( 'display', 'none' );
                            }

                            let form_control_lang_new = add_new_lang.find( '.form-control-lang-new' );
                            form_control_lang_new.val( k );
                            form_control_lang_new.attr( 'data-lang', k );

                            let meta = form_control_lang_new.cs_select2( {
                                closeOnSelect: true,
                                allowClear: false,
                            } ).on( 'cs_select2:select', function ( event ) {

                                let js_control_id = $( this ).closest( '.cs_data_render_wrap' ).find( '.js-control-element' ).attr( 'id' );
                                cs_select2_processing( event, $( this ), js_control_id );
                            } ).attr( 'data-option-type' );

                            let name = '';
                            if ( meta == 1 ) {
                                name = key + '_' + k;
                            } else {
                                name = 'cs[' + data_add.attr( 'data-plugin-name' ) + '][' + key + '_' + k + ']';
                            }

                            if ( render == 'renderWpEditor' || render == 'renderWpEditorByTerm' ) {

                                let id, textarea;

                                if ( render == 'renderWpEditorByTerm' ) {
                                    add_new_lang.find( '.cs_cookie_cat_title' ).val( lang_list[ k ][ 'value' ][ 'name' ] );
                                    id = 'cs_edit_cat_description_' + ( new Date() ).getTime();
                                    textarea = '<textarea id="' + id + '" name="cs_edit_cat_description_' + k + '" class="cs_cookie_cat_description">' + lang_list[ k ][ 'value' ][ 'descr' ] + '</textarea>';
                                } else {
                                    id = key + '_' + ( new Date() ).getTime();
                                    textarea = '<textarea id="' + id + '" name="' + name + '">' + lang_list[ k ][ 'value' ] + '</textarea>';
                                }

                                add_new_lang.find( '.cs_data_render' ).append( textarea );
                                init_wp_editor( id );

                                let class_list = data_add.closest( '.card-body' ).find( '.input_row_default .cs_data_render_wrap textarea' ).attr( "class" );
                                if ( class_list !== undefined ) {
                                    class_list.split( /\s+/ );
                                    $( '#' + id ).addClass( class_list );
                                }

                            } else if ( render == 'renderTextInput' ) {
                                let id = key + '_' + ( new Date() ).getTime(),
                                    input = '<input type="text" class="js-control-element" id="' + id + '" name="' + name + '" value="' + lang_list[ k ][ 'value' ] + '">',
                                    class_list = data_add.closest( '.cart_line_item' ).find( '.input_row_default .cs_data_render_wrap input' ).attr( "class" ).split( /\s+/ );

                                $( '#' + id ).addClass( class_list );
                                add_new_lang.find( '.cs_data_render' ).append( input );
                            }
                        }
                    } else {
                        if ( typeof data.data.message !== 'undefined' ) {
                            language_block.find( '.language_list' ).html( '<p class="cs_empty_langs">' + data.data.message + '</p>' );
                        }
                    }

                    if ( data.success ) {
                        language_block.find( '.cs_input_language_control' ).val( '1' );
                    }

                    setTimeout( function () {
                        language_block.find( '.cs_lang_loading' ).css( 'display', 'none' );
                    }, 500 );
                },
                error: function ( response ) {
                    console.log( response );
                }
            } );
            $( this ).unbind( click_event );
        } );

        //show popup overlay
        function cs_show_popup_overlay() {
            $( '.preview_wrap .cs_popup_overlay' ).css( {
                visibility: 'visible',
                opacity: 1,
            } );
        }

        /**
         * IAB Settings
         */

        //Search vendor
        $( '#cs_search_vendor' ).on( 'input', function () {
            let vendors = $( '#cs_vendor_list .list-item-large' ),
                search = $( this ).val().toLowerCase(),
                display_number = 0;

            vendors.parent().addClass( 'filtered' );

            if ( vendors.length > 0 ) {
                vendors.each( function ( i, item ) {
                    let name = $( item ).find( '.cs_vendor_name' ).html().toLowerCase();
                    if ( name.indexOf( search ) !== -1 ) {
                        $( item ).show();
                        if ( display_number % 2 === 1 ) {
                            $( item ).css( 'background', '#f9f9f9' );
                        } else {
                            $( item ).css( 'background', 'none' );
                        }
                        display_number++;
                    } else {
                        $( item ).hide();
                    }
                } )
            }
        } )

        //Search additional vendor
        $( '#cs_search_additional_vendor' ).on( 'input', function () {
            let vendors = $( '#cs_additional_vendor_list .list-item-large' ),
                search = $( this ).val().toLowerCase(),
                display_number = 0;

            vendors.parent().addClass( 'filtered' );

            if ( vendors.length > 0 ) {
                vendors.each( function ( i, item ) {
                    let name = $( item ).find( '.cs_vendor_name' ).html().toLowerCase();
                    if ( name.indexOf( search ) !== -1 ) {
                        $( item ).show();
                        if ( display_number % 2 === 1 ) {
                            $( item ).css( 'background', '#f9f9f9' );
                        } else {
                            $( item ).css( 'background', 'none' );
                        }
                        display_number++;
                    } else {
                        $( item ).hide();
                    }
                } )
            }
        } )

        //Change vendor settings
        $( '#cs_iab_settings .cs_iab_show_only_vendors_details .cs-vendor-input' ).on( 'change', function () {
            let vendor_settings = $( '#cs_iab_settings #cs_iab_vendor_settings' ),
                settings = vendor_settings.val(),
                vendor_id = $( this ).data( 'vendor_id' );

            settings = settings ? JSON.parse( settings ) : {};
            settings[ vendor_id ] = +$( this ).prop( 'checked' );
            vendor_settings.val( JSON.stringify( settings ) );
        } )

        //Change additional vendor settings
        $( '#cs_iab_settings .cs_iab_show_only_additional_vendors_details .cs-additional-vendor-input' ).on( 'change', function () {
            let vendor_settings = $( '#cs_iab_settings #cs_iab_additional_vendor_settings' ),
                settings = vendor_settings.val(),
                vendor_id = $( this ).data( 'vendor_id' );

            settings = settings ? JSON.parse( settings ) : {};
            settings[ vendor_id ] = +$( this ).prop( 'checked' );
            vendor_settings.val( JSON.stringify( settings ) );
        } )

        //Get vendor cookie details
        $( document ).on( 'click.cs_click_url', '#cs_iab_settings .cs_vendor_cookie_details', function ( e ) {
            e.preventDefault();

            let click_container = $( this ),
                id = parseInt( $( this ).data( 'vendorid' ) ),
                url = CS_Admin_Data.cs_vendor_list.vendors[ id ].deviceStorageDisclosureUrl,
                $target = $( this ).closest( '.cs_vendor_cookie_details_wrap' ).find( '.cs_vendor_description_data' );

            click_container.removeClass( 'cs_vendor_cookie_details' );

            $.ajax( {
                url: url,
                type: 'GET',
                beforeSend: function () {
                    // setting a timeout
                    click_container.find( 'a' ).append( '...' );
                },
                success: function success( response ) {

                    if ( Object.keys( response.disclosures ).length > 0 ) {
                        let table =
                            '<table>' +
                            '<thead>' +
                            '<tr>' +
                            '<th class="cs_item_description_data_table_col_1">' + CS_Admin_Data.cs_translations.cs_iab_name + '</th>' +
                            '<th class="cs_item_description_data_table_col_2">' + CS_Admin_Data.cs_translations.cs_iab_domain + '</th>' +
                            '<th class="cs_item_description_data_table_col_3">' + CS_Admin_Data.cs_translations.cs_iab_purposes + '</th>' +
                            '<th class="cs_item_description_data_table_col_4">' + CS_Admin_Data.cs_translations.cs_iab_expiry + '</th>' +
                            '<th class="cs_item_description_data_table_col_5">' + CS_Admin_Data.cs_translations.cs_iab_type + '</th>' +
                            '</tr>' +
                            '</thead>' +
                            '<tbody>';

                        response.disclosures.forEach( ( item ) => {
                            table +=
                                '<tr>' +
                                '<td class="cs_item_description_data_table_col_1"> ' +
                                item.identifier +
                                '</td>' +
                                '<td class="cs_item_description_data_table_col_2">';

                            if ( item.domains && typeof item.domains == 'object' ) {
                                item.domains.forEach( ( domain ) => {
                                    table += domain;
                                } )
                            } else if ( item.domain && typeof item.domain == 'string' ) {
                                table += item.domain;
                            }
                            table +=
                                '</td>' +
                                '<td class="cs_item_description_data_table_col_3">';
                            if ( item.purposes ) {
                                table += '<ul>';
                                item.purposes.forEach( ( purpose ) => {
                                    table += '<li>' + CS_Admin_Data.cs_vendor_list.purposes[ purpose ].name + '</li>';
                                } );
                                table += '</ul>';
                            }

                            table += '</td>' +
                                '<td class="cs_item_description_data_table_col_4">' +
                                getTimeInterval( item.maxAgeSeconds ) +
                                '</td>' +
                                '<td class="cs_item_description_data_table_col_5">' +
                                item.type +
                                '</td>' +
                                '</tr>';
                        } )
                        table +=
                            '</tbody>' +
                            '</table>';

                        $target.prepend( table );

                    } else {
                        $target.prepend( CS_Admin_Data.cs_translations.cs_iab_nodata );
                    }
                },
                error: function error( response ) {
                    console.log( 'Error: ', response );
                    $target.prepend( CS_Admin_Data.cs_translations.cs_iab_nodata );
                },
                complete: function () {
                    click_container.find( 'a' ).html( CS_Admin_Data.cs_translations.cs_iab_cookie_details + ':' );
                },
            } );

        } );

        /**
         * Actions with iab consent
         */

        //Tab switching
        $( document ).on( 'click', '.cs_preview_container .cs_sub_tab__popup_content li', function () {
            let trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).closest( '.cs-modal-content' ),
                ctnr = prnt.find( '.cs_sub_tab_container' ),
                more_options = $( '.cs-tab-footer .cs_more_options_btn' ),
                setting_save = $( '.cs-tab-footer .cs_setting_save_button' );

            prnt.find( '.cs_sub_tab > li' ).removeClass( 'active' );
            $( this ).addClass( 'active' );
            ctnr.find( '.cs_sub_tab_content_iab' ).hide();
            ctnr.find( '.cs_sub_tab_content_iab[data-id="' + trgt + '"]' ).fadeIn();
            if ( trgt == 'consent' ) {
                more_options.show();
                setting_save.hide();
            } else {
                more_options.hide();
                setting_save.show();
            }
        } );

        //More options button action
        $( document ).on( 'click', '#cs_preview_popup .cs_more_options_btn', function ( e ) {
            e.preventDefault();
            $( '#cs_preview_popup .cs_sub_tab__popup_content li[data-target=options]' ).trigger( 'click' );
        } );

        $( document ).on( 'click', '.cs_preview_container .cs_card-header', function () {
            let e = $( this ).closest( ".cs_card" ).find( ".cs_card-body" );
            let i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.fadeOut().removeClass( "show" ) : e.fadeIn().addClass( "show" );
            i.hasClass( "icon-up-arrow" ) ? i.removeClass( "icon-up-arrow" ).addClass( "icon-down" ) : i.removeClass( "icon-down" ).addClass( "icon-up-arrow" );
        } );

        //build vendor details
        $( document ).on( 'click', '#cs_iab_settings .cs_iab_vendor_details', function () {
            if ( !$( this ).data( 'cs-built' ) ) {
                let vendor_list = CS_Admin_Data.cs_vendor_list;

                if ( Object.keys( vendor_list ).length === 0 ) {
                    return;
                }

                let data = '',
                    container = $( this ),
                    vendor_container = container.closest( '.cs_iab_vendor_container' ),
                    container_to_add = vendor_container.find( '.details-col' ),
                    id = parseInt( vendor_container.find( '.cs-vendor-input' ).data( 'vendor_id' ) ),
                    privacyByLang,
                    legitimateInterestByLang;

                if ( Object.keys( vendor_list.vendors[ id ].urls ).length > 1 && CS_Admin_Data.cs_iab.current_iab_lang ) {

                    const names = vendor_list.vendors[ id ].urls.map( item => item.langId );
                    let i = names.indexOf( CS_Admin_Data.cs_iab.current_iab_lang );

                    if ( i !== -1 ) {
                        privacyByLang = vendor_list.vendors[ id ].urls[ i ].hasOwnProperty( 'privacy' ) ? vendor_list.vendors[ id ].urls[ i ].privacy : '';
                        legitimateInterestByLang = vendor_list.vendors[ id ].urls[ i ].hasOwnProperty( 'legIntClaim' ) ? vendor_list.vendors[ id ].urls[ i ].legIntClaim : '';
                    } else {
                        privacyByLang = vendor_list.vendors[ id ].urls[ 0 ].hasOwnProperty( 'privacy' ) ? vendor_list.vendors[ id ].urls[ 0 ].privacy : '';
                        legitimateInterestByLang = vendor_list.vendors[ id ].urls[ 0 ].hasOwnProperty( 'legIntClaim' ) ? vendor_list.vendors[ id ].urls[ 0 ].legIntClaim : '';
                    }
                } else {
                    privacyByLang = vendor_list.vendors[ id ].urls[ 0 ].hasOwnProperty( 'privacy' ) ? vendor_list.vendors[ id ].urls[ 0 ].privacy : '';
                    legitimateInterestByLang = vendor_list.vendors[ id ].urls[ 0 ].hasOwnProperty( 'legIntClaim' ) ? vendor_list.vendors[ id ].urls[ 0 ].legIntClaim : '';
                }

                if ( privacyByLang.length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_privacy_policy + '</div>';
                    data += '<div class="cs_vendor_link_wrap">';
                    data += '<a href="' + privacyByLang + '" target="_blank" class="cs_vendor_link">' + privacyByLang + '</a>';
                    data += '</div></div>';
                }

                if ( legitimateInterestByLang.length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_legitimate_interest + '</div>';
                    data += '<div class="cs_vendor_link_wrap">';
                    data += '<a href="' + legitimateInterestByLang + '" target="_blank" class="cs_vendor_link">' + legitimateInterestByLang + '</a>';
                    data += '</div></div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].purposes ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_purposes + '</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].purposes.forEach( ( i ) => {
                        if ( typeof vendor_list.purposes[ i ] !== 'undefined' ) {
                            let time = typeof vendor_list.vendors[ id ].dataRetention.purposes[ i ] !== 'undefined' ? vendor_list.vendors[ id ].dataRetention.purposes[ i ] : ( vendor_list.vendors[ id ].dataRetention.hasOwnProperty( 'stdRetention' ) ? vendor_list.vendors[ id ].dataRetention.stdRetention : 0 );
                            data += '<li>' + vendor_list.purposes[ i ].name + ' ' + ( time ? ' (' + CS_Admin_Data.cs_translations.cs_iab_days.replace( '%', time ) + ')' : '' ) + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].legIntPurposes ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_purposes + ' (' + CS_Admin_Data.cs_translations.cs_iab_legitimate_interest + ')</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].legIntPurposes.forEach( ( i ) => {
                        if ( typeof vendor_list.purposes[ i ] !== 'undefined' ) {
                            let time = typeof vendor_list.vendors[ id ].dataRetention.purposes[ i ] !== 'undefined' ? vendor_list.vendors[ id ].dataRetention.purposes[ i ] : ( vendor_list.vendors[ id ].dataRetention.hasOwnProperty( 'stdRetention' ) ? vendor_list.vendors[ id ].dataRetention.stdRetention : 0 );
                            data += '<li>' + vendor_list.purposes[ i ].name + ' ' + ( time ? ' (' + CS_Admin_Data.cs_translations.cs_iab_days.replace( '%', time ) + ')' : '' ) + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].specialPurposes ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_special_purposes + '</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].specialPurposes.forEach( ( i ) => {
                        if ( typeof vendor_list.specialPurposes[ i ] !== 'undefined' ) {
                            let time = typeof vendor_list.vendors[ id ].dataRetention.specialPurposes[ i ] !== 'undefined' ? vendor_list.vendors[ id ].dataRetention.specialPurposes[ i ] : ( vendor_list.vendors[ id ].dataRetention.hasOwnProperty( 'stdRetention' ) ? vendor_list.vendors[ id ].dataRetention.stdRetention : 0 );
                            data += '<li>' + vendor_list.specialPurposes[ i ].name + ' ' + ( time ? ' (' + CS_Admin_Data.cs_translations.cs_iab_days.replace( '%', time ) + ')' : '' ) + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].features ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_features + '</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].features.forEach( ( i ) => {
                        if ( typeof vendor_list.features[ i ] !== 'undefined' ) {
                            data += '<li>' + vendor_list.features[ i ].name + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].specialFeatures ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_special_features + '</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].specialFeatures.forEach( ( i ) => {
                        if ( typeof vendor_list.specialFeatures[ i ] !== 'undefined' ) {
                            data += '<li>' + vendor_list.specialFeatures[ i ].name + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                if ( ( typeof vendor_list.vendors[ id ].dataDeclaration !== 'undefined' ) && Object.keys( vendor_list.vendors[ id ].dataDeclaration ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_data_categories + '</div>';
                    data += '<ul>';

                    vendor_list.vendors[ id ].dataDeclaration.forEach( ( i ) => {
                        if ( typeof vendor_list.dataCategories[ i ] !== 'undefined' ) {
                            data += '<li>' + vendor_list.dataCategories[ i ].name + '</li>';
                        }
                    } );

                    data += '</ul>';
                    data += '</div>';
                }

                let preferences = [];
                if ( vendor_list.vendors[ id ].cookieMaxAgeSeconds ) {
                    preferences[ 'cookieMaxAgeSeconds' ] = getTimeInterval( vendor_list.vendors[ id ].cookieMaxAgeSeconds );
                }

                if ( vendor_list.vendors[ id ].cookieRefresh ) {
                    preferences[ 'cookieRefresh' ] = CS_Admin_Data.cs_translations.cs_iab_cookie_refreshed;
                }

                if ( vendor_list.vendors[ id ].usesCookies || vendor_list.vendors[ id ].usesNonCookieAccess ) {
                    let cookies = CS_Admin_Data.cs_translations.cs_iab_storage_methods + ':&nbsp;';

                    if ( vendor_list.vendors[ id ].usesCookies ) {
                        cookies += CS_Admin_Data.cs_translations.cs_iab_cookies_and_others;
                    } else if ( !vendor_list.vendors[ id ].usesCookies && vendor_list.vendors[ id ].usesNonCookieAccess ) {
                        cookies += CS_Admin_Data.cs_translations.cs_iab_other_methods;
                    }
                    preferences[ 'cookies' ] = cookies;
                }

                if ( Object.keys( preferences ).length > 0 ) {
                    data += '<div class="mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_consent_preferences + '</div>';
                    data += '<ul>';

                    for ( let i in preferences ) {
                        data += '<li>' + preferences[ i ] + '</li>';
                    }

                    data += '</ul>';
                    data += '</div>';
                }

                if ( Object.keys( vendor_list.vendors[ id ].deviceStorageDisclosureUrl ).length > 0 ) {
                    data += '<div class="cs_vendor_cookie_details_wrap mt-10 mb-10">';
                    data += '<div class="fw600 cs_vendor_cookie_details" data-vendorid="' + id + ' ">';
                    data += '<a>' + CS_Admin_Data.cs_translations.cs_iab_show_cookie_details + '</a>'
                    data += '</div>';
                    data += '<div class="cs_vendor_description_data"></div>';
                    data += '</div>';
                }

                container_to_add.find( '.list-item-description' ).append( data );
                container.attr( 'data-cs-built', 1 );
            }

            $( this ).toggleText( 'Details', 'Close' );
            let tr = $( this ).closest( '.row' ).find( '.details-col' );
            tr.slideToggle();
        } );

        //build additional vendor detail
        $( document ).on( 'click', '#cs_iab_settings .cs_iab_additional_vendor_details', function () {
            if ( !$( this ).data( 'cs-built' ) ) {
                let data = '',
                    container = $( this ),
                    vendor_container = container.closest( '.cs_iab_vendor_container' ),
                    container_to_add = vendor_container.find( '.details-col' ),
                    vendor_list = CS_Admin_Data.cs_vendor_list,
                    id = parseInt( vendor_container.find( '.cs-additional-vendor-input' ).data( 'vendor_id' ) );

                if ( vendor_list.additional_vendors[ id ].privacy_policy.length > 0 ) {
                    data += '<div class="cs_sub_sub_card_item_description mt-10 mb-10">';
                    data += '<div class="fw600">' + CS_Admin_Data.cs_translations.cs_iab_privacy_policy + '</div>';
                    data += '<div class="cs_vendor_link_wrap">';
                    data += '<a href="' + vendor_list.additional_vendors[ id ].privacy_policy + '" target="_blank" class="cs_vendor_link">' + vendor_list.additional_vendors[ id ].privacy_policy + '</a>';
                    data += '</div></div>';
                }

                container_to_add.find( '.list-item-description' ).append( data );
                container.attr( 'data-cs-built', 1 );
            }

            $( this ).toggleText( 'Details', 'Close' );
            let tr = $( this ).closest( '.row' ).find( '.details-col' );
            tr.slideToggle();
        } )

        //open property details in popup preview
        $( document ).on( 'click', '#cs_preview_popup .cs_card-header', function () {
            let e = $( this ).closest( ".cs_card_single" ).find( ".cs_card-body" );
            let i = $( this ).find( "i" );
            e.hasClass( "show" ) ? e.fadeOut().removeClass( "show" ) : e.fadeIn().addClass( "show" );
            i.hasClass( "icon-chevron-right-arrow" ) ? i.removeClass( "icon-chevron-right-arrow" ).addClass( "icon-chevron-down-arrow" ) : i.removeClass( "icon-chevron-down-arrow" ).addClass( "icon-chevron-right-arrow" );
        } );

        //toggle vendors tab
        $( document ).on( 'click', '#cs_preview_popup .cs_sub_sub_tab__popup_content li', function () {
            let trgt = $( this ).attr( 'data-target' ),
                prnt = $( this ).closest( '.cs_card-body' ),
                ctnr = prnt.find( '.cs_sub_tab_container' );

            prnt.find( '.cs_sub_sub_tab > li' ).removeClass( 'active-type2' );
            $( this ).addClass( 'active-type2' );
            ctnr.find( '.cs_sub_sub_tab_content_iab' ).hide();
            ctnr.find( '.cs_sub_sub_tab_content_iab[data-id="' + trgt + '"]' ).fadeIn();
        } );

        //toggle more options in the popup
        $( document ).on( 'click', '#cs_preview_popup .cs_more_options_btn', function ( e ) {
            e.preventDefault();
            $( '#cs_preview_popup .cs_sub_tab__popup_content li[data-target=details]' ).trigger( 'click' );
        } );

        //scroll to vendors
        $( document ).on( 'click', '#cs_preview_popup .cs_open_vendors', function ( e ) {
            e.preventDefault();

            if ( e.target.matches( '.open' ) ) {
                $( '.options_btn' ).trigger( 'click' );
            }
            if ( !e.target.matches( '.current' ) ) {
                $( '#cs_preview_popup .cs_sub_tab__popup_content li[data-target="options"]' ).trigger( 'click' );
            }
            let header = $( '#cs_card-header-vendors' );
            header.closest( ".cs_card_single" ).find( ".cs_card-body" ).fadeIn().addClass( "show" );
            header.find( "i" ).removeClass( "icon-chevron-right-arrow" ).addClass( "icon-chevron-down-arrow" );
            let top = document.getElementById( 'cs_card-header-vendors' ).offsetTop;
            $( '#cs-modal-body' ).animate( { scrollTop: top - 90 }, 1500 );
        } );

        /**
         * Toggle export settings checkbox
         */
        $( '#cs_export_settings .cs_all_settings' ).on( 'click', function () {

            let checkboxes = $( '#cs_export_settings input[type=checkbox]' );
            if ( $( this ).is( ':checked' ) ) {
                checkboxes.prop( "checked", true );
            } else {
                checkboxes.prop( "checked", false );
            }
        } )

        /**
         * Export settings
         */
        $( '.cs_export_settings' ).on( 'click', function ( e ) {
            e.preventDefault();
            let post_data = {
                    iab_settings: $( 'input[type=checkbox].cs_iab_settings' ).prop( 'checked' ),
                    general_settings: $( 'input[type=checkbox].cs_general_settings' ).prop( 'checked' ),
                    geolocation_settings: $( 'input[type=checkbox].cs_geolocation_settings' ).prop( 'checked' ),
                    default_rules: $( 'input[type=checkbox].cs_default_rules' ).prop( 'checked' ),
                    custom_rules: $( 'input[type=checkbox].cs_custom_rules' ).prop( 'checked' ),
                    predefined_scripts: $( 'input[type=checkbox].cs_predefined_scripts' ).prop( 'checked' ),
                    custom_scripts: $( 'input[type=checkbox].cs_custom_scripts' ).prop( 'checked' ),
                    design_settings: $( 'input[type=checkbox].cs_design_settings' ).prop( 'checked' ),
                    script_types: $( 'input[type=checkbox].cs_script_types' ).prop( 'checked' ),
                    text: $( 'input[type=checkbox].cs_text' ).prop( 'checked' ),
                    nonce_code: cmpro_ajax.nonce,
                    action: 'cs_export_settings'
                },
                message = $( '.cs_settings_message' );

            $.ajax( {
                type: "POST",
                data: post_data,
                url: cmpro_ajax.ajaxurl,
                beforeSend: function () {
                    message.html( 'Export processing...' );
                },
                success: function ( response ) {
                    let link = document.createElement( 'a' );
                    link.href = "data:text/json;charset=utf-8," + encodeURIComponent( response );
                    link.download = 'export.json'
                    document.body.appendChild( link );
                    link.click();
                    message.html( 'Export completed' );
                },
                error: function ( response ) {
                    console.log( 'ERROR' );
                    console.log( response );
                    message.html( 'Something went wrong' );
                }
            } );
        } );

        /**
         * Import settings
         */
        $( "#cs_import_settings" ).on( 'change', function () {
            let data = new FormData(),
                message = $( '.cs_settings_message' );
            data.append( "nonce_code", cmpro_ajax.nonce );
            data.append( "action", "cs_import_settings" );
            data.append( $( this ).attr( "name" ), $( this ).prop( 'files' )[ 0 ] );

            $.ajax( {
                url: cmpro_ajax.ajaxurl,
                data: data,
                processData: false,
                contentType: false,
                type: 'POST',
                beforeSend: function () {
                    message.html( 'Import processing...' );
                },
                success: function ( response ) {
                    if ( response.success ) {
                        message.html( response.data );
                    } else {
                        message.html( response.data );
                    }
                },
                error: function ( response ) {
                    console.log( 'ERROR' );
                    console.log( response );
                    message.html( 'Something went wrong' );
                }
            } );
        } );

        $( 'select[name="cs[consent-magic][cs_user_default_language]"]' ).on( 'change', function () {

            let lang = $( this ).find( ':selected' ).val(),
                lang_container = $( 'input[name="cs[consent-magic][cs_language_availability][' + lang + ']"]' ).closest( '.cs_available_lang_container' ),
                lang_message = $( '#cs_language_message' ).html();

            $( '.cs_available_lang_container' ).each( function () {
                $( this ).css( {
                    'opacity': '1',
                    'pointer-events': 'auto'
                } );
                $( this ).find( '.cs_language_message' ).html( '' );
            } )

            lang_container.css( {
                'opacity': '0.5',
                'pointer-events': 'none'
            } )

            lang_container.find( '.custom-switch-input' ).prop( 'checked', true );
            lang_container.find( '.cs_language_message' ).html( lang_message );
        } );

        function update_target( select, state_update, scroll_state, status ) {
            if ( state_update ) {
                let usa_options = select.find( 'optgroup[id="cs_target_states_group"] option' );

                usa_options.each( function () {
                    $( this ).prop( 'selected', status );
                } );

                select.cs_select2( {
                    closeOnSelect: false,
                    dropdownCssClass: "cs_location",
                    allowClear: false,
                    matcher: target_matcher,
                    templateResult: formatResult,
                } );
                select.cs_select2( "open" );

                if ( scroll_state ) {
                    let dropdown = $( ".cs_select2-dropdown" ),
                        option = dropdown.find( '.cs_select2-results__option[aria-selected] > span[data-country=US]' );
                    if ( option.length ) {
                        let results = dropdown.find( ".cs_select2-results > .cs_select2-results__options" );
                        results.scrollTop( option.position().top + results.scrollTop() - results.height() / 2 );
                    }
                }

                select.trigger( 'change' );
            }

            let selected_states = select.find( 'optgroup[id="cs_target_states_group"] option:selected' ),
                selected_countries = select.find( 'option[class="country"]:selected' );

            let target_states = selected_states.map( function () {
                return $( this ).data( 'value' );
            } ).get();
            target_states = target_states.join( ',' );
            $( '#cs_states_target' ).val( target_states );

            let target_countries = selected_countries.map( function () {
                return $( this ).val();
            } ).get();
            target_countries = target_countries.join( ',' );
            $( '#cs_countries_target' ).val( target_countries );

        }
    } );

} )( jQuery );

function cs_store_settings_btn_click( vl ) {
    document.getElementById( 'cs_update_action' ).value = vl;
}

function init_wp_editor( id ) {
    wp.editor.initialize( id, {
        tinymce: {
            wpautop: true,
            skin: 'lightgray',
            relative_urls: false,
            remove_script_host: false,
            convert_urls: false,
            browser_spellcheck: true,
            fix_list_elements: true,
            resize: 'vertical',
            body_class: '',
            preview_styles: 'font-family font-size font-weight font-style text-decoration text-transform',
            wpeditimage_disable_captions: false,
            wpeditimage_html5_captions: true,
            toolbar1: 'bold,italic,underline,blockquote,strikethrough,bullist,numlist,alignleft,aligncenter,alignright,undo,redo,link,spellchecker,fullscreen',
        },
        quicktags: true,
        mediaButtons: false,
    } );
}

function copyShortcode( val, that ) {
    /* Copy the text inside the text field */
    navigator.clipboard.writeText( val );
    let popup = jQuery( that ).closest( '.wrap_title' ).append( '<div class="cs_preview_container cs_renew_consent_wrap">' +
        '<div class="cs-modal cs-blowup">' +
        '<div class="cs-info-bar cs-public-cookie-popup popup_small">Copied the shortcode: ' + val + '</div>' +
        '</div>' +
        '</div>' );
    setTimeout( function () {
        jQuery( that ).closest( '.wrap_title' ).find( '.cs_preview_container' ).remove();
    }, 1000 );
}

const CS_Cookie = {
    set: function ( name, value, days ) {
        let expires;
        if ( days ) {
            let date = new Date();
            date.setTime( date.getTime() + ( days * 24 * 60 * 60 * 1000 ) );
            expires = "; expires=" + date.toGMTString();
        } else
            expires = "";
        document.cookie = name + "=" + value + expires + "; path=/";
    },
    read: function ( name ) {
        let nameEQ = name + "=",
            ca = document.cookie.split( ';' );
        for ( let i = 0; i < ca.length; i++ ) {
            let c = ca[ i ];
            while ( c.charAt( 0 ) == ' ' ) {
                c = c.substring( 1, c.length );
            }
            if ( c.indexOf( nameEQ ) === 0 ) {
                return c.substring( nameEQ.length, c.length );
            }
        }
        return null;
    },
    erase: function ( name ) {
        this.set( name, "", -10 );
    },
    exists: function ( name ) {
        return ( this.read( name ) !== null );
    }
}

function getTimeInterval( seconds ) {
    let interval = '';
    window.dayjs.extend( window.dayjs_plugin_duration );
    let time = window.dayjs.duration( seconds * 1000 );

    let y = time.years();
    interval += y !== 0 ? CS_Admin_Data.cs_translations.cs_iab_years.replace( '%', y ) + '&nbsp;' : '';
    let m = time.months();
    interval += m !== 0 ? CS_Admin_Data.cs_translations.cs_iab_months.replace( '%', m ) + '&nbsp;' : '';
    let d = time.days();
    interval += d !== 0 ? CS_Admin_Data.cs_translations.cs_iab_days.replace( '%', d ) + '&nbsp;' : '';
    let h = time.hours();
    interval += h !== 0 ? CS_Admin_Data.cs_translations.cs_iab_hours.replace( '%', h ) + '&nbsp;' : '';
    let i = time.minutes();
    interval += i !== 0 ? CS_Admin_Data.cs_translations.cs_iab_minutes.replace( '%', i ) + '&nbsp;' : '';

    return interval;
}