<?php

namespace ConsentMagicPro;

// If this file is called directly, abort.
if ( !defined( 'WPINC' ) ) {
	die;
}

$id = sanitize_text_field( $_GET[ 'primary_rule_id' ] );

$unassigned    = get_term_by( 'slug', 'unassigned', 'cs-cookies-category' );
$unassigned_id = $unassigned->term_id;
$options       = get_cookies_terms_objects( null, false, $unassigned_id );
$current_lang  = get_general_language( get_locale() );
$cs_type       = get_post_meta( $id, '_cs_type', true );
$design_type   = get_post_meta( $id, '_cs_design_type', true );

$cs_user_default_language = ConsentMagic()->getOption( 'cs_user_default_language' );
$cs_language_availability = ConsentMagic()->getOption( 'cs_language_availability' );
if ( isset( $cs_language_availability[ $current_lang ] ) && $cs_language_availability[ $current_lang ] == 0 ) {
	$current_lang = $cs_user_default_language;
}

?>
<div class="wrap">
    <h2 class="wp-heading-inline"><?php esc_html_e( 'Edit', 'consent-magic' ); ?><?php echo ' ' . esc_html( get_the_title( $id ) ); ?></h2>
    <form method="post" action="<?php echo get_admin_url() . 'admin.php?page=consent-magic'; ?>" id="cs_settings_form">
        <input type="hidden" name="cs_update_action" value="" id="cs_update_action"/>
        <input type="hidden" name="cs_rule_id" value="<?php echo esc_attr( $id ); ?>" id="cs_rule_id"/>
		<?php
		// Set nonce:
		if ( function_exists( 'wp_nonce_field' ) ) {
			wp_nonce_field( 'cs-update-' . CMPRO_SETTINGS_FIELD );
		} ?>
        <div class="cs-tab-container">
            <div class="cs-tab-content" style="display: block;">
                <div class="container edit_rule_container">

					<?php
					//save button
					include CMPRO_PLUGIN_VIEWS_PATH . "admin/buttons/admin-rules-save-button.php";
					?>
					<?php if ( get_post_meta( $id, '_cs_predefined_rule', true ) == 0 ) { ?>
                        <div class="rules-wrap">
                            <div class="row list-item">
                                <div class="col-12">
                                    <h3><?php esc_html_e( 'Edit Rule name:', 'consent-magic' ); ?></h3>
                                    <div>
                                        <input type="text" name="cs_post_name" id="cs_post_name"
                                               class="form-control js-control-element"
                                               value="<?php echo esc_attr( get_the_title( $id ) ); ?>"/>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php } ?>

                    <div class="rules-wrap">
                        <div class="row list-item">
                            <div class="col-12">
								<?php echo render_switcher_input( '_cs_enable_rule', false, true, $id ); ?>
                                <h3 class="indicator-label switcher-label"><?php esc_html_e( 'Enable Rule', 'consent-magic' ); ?></h3>
                            </div>
                        </div>
                    </div>

                    <div class="rules-wrap">
                        <div class="row list-item">
                            <div class="col-12">
                                <h3 class="indicator-label"><?php esc_html_e( 'Locations:', 'consent-magic' ); ?></h3>
                            </div>

                            <div class="col-12 cs_location">
								<?php renderSelectLocation( '_cs_general_target', $id, true ); ?>
                            </div>

                            <div class="col-12" style="margin-top: 30px;">
								<?php if ( get_the_title( $id ) == 'GDPR Rule' && !metadata_exists( 'post', $id, '_cs_no_ip_rule' ) ) {
									update_post_meta( $id, '_cs_no_ip_rule', 1 );
									echo render_switcher_input( '_cs_no_ip_rule', false, true, $id );
								} else {
									echo render_switcher_input( '_cs_no_ip_rule', false, true, $id );
								} ?>
                                <h4 class="indicator-label switcher-label"><?php esc_html_e( "Show this rule when we can't retrieve the IP", 'consent-magic' ); ?></h4>
                            </div>
                        </div>
                    </div>

                    <div class="rules-wrap">
                        <div class="row list-item">
                            <div class="col-12">
                                <h3 class="indicator-label"><?php esc_html_e( 'Consent type:', 'consent-magic' ); ?></h3>
                            </div>

                            <div class="col-12">
								<?php renderSelectInput_meta( '_cs_type', $id, renderCSTypeOptions(), true ); ?>
                            </div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'ask_before_tracking' || $cs_type == 'inform_and_opiout' ) ? '' : 'style="display:none;"'; ?>>
                            <div class="cs-line mb-30 mt-30"></div>

							<?php if ( !CS_Meta_LDU()->check_pys_version() ) : ?>
                                <span class="dimmy_checkbox">
                                    <?php echo render_switcher_input( '_cs_use_meta_ldu', false, true, null, false, false, __( 'For Meta, use the Limited Data Use (LDU) flag instead of blocking the browser and API events', 'consent-magic' ) ); ?>
                                </span>
                            <?php else : ?>
                                <?php echo render_switcher_input( '_cs_use_meta_ldu', false, true, $id, false, false, __( 'For Meta, use the Limited Data Use (LDU) flag instead of blocking the browser and API events', 'consent-magic' ) ); ?>
                            <?php endif; ?>

	                        <?php if ( !CS_Meta_LDU()->check_pys_version() ) : ?>
                                <p style="color:#f30000;margin-bottom: 0;" class="ml-60"><?php esc_html_e( 'This option needs PixelYourSite Professional version 11.2.1 or more, or PixelYourSite free version 10.1.0 or more.', 'consent-magic' ); ?></p>
	                        <?php endif; ?>

                            <p class="ml-60"><?php esc_html_e( 'It works ONLY when the pixel and API events are configured with the PixelYourSite plugin.', 'consent-magic' ); ?>&nbsp;<?php echo wp_kses_post( sprintf( __( 'Details %shere%s', 'consent-magic' ), '<a href="https://www.facebook.com/business/help/1151133471911882/" target="_blank">', '</a>' ) ); ?></p>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'ask_before_tracking' || $cs_type == 'iab' || $cs_type == 'inform_and_opiout' ) ? '' : 'style="display:none;"'; ?>>
                            <div class="cs-line cs_showing_line mb-30 mt-30" <?php echo $cs_type == 'iab' ? '' : 'style="display:none;"'; ?>></div>
							<?php echo render_switcher_input( '_cs_google_consent_mode', false, true, $id, false, false, __( 'For Google Tags, use Google Consent Mode instead of blocking the scripts', 'consent-magic' ) ); ?>
                            <p class="ml-60"><?php echo wp_kses_post( sprintf( __( 'Details %shere%s', 'consent-magic' ), '<a href="https://support.google.com/google-ads/answer/10000067?hl=en" target="_blank">', '</a>' ) ); ?></p>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type != 'iab' ) ? 'style="display:none;"' : ''; ?>>
                            <div class="cs-line mb-30 mt-30"></div>
							<?php echo render_switcher_input( '_cs_native_scripts', false, true, $id, false, false, __( 'Enable ConsentMagic native script controls', 'consent-magic' ) ); ?>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
                            <div class="cs-line mb-30 mt-30"></div>
							<?php echo render_switcher_input( '_cs_sticky', false, true, $id, false, $cs_type == 'iab', __( 'Sticky', 'consent-magic' ), false, $cs_type == 'iab' ? 'disabled' : false ); ?>
                            <p><?php esc_html_e( 'Show a small consent bar after consent is express', 'consent-magic' ); ?></p>

                            <div class="ml-20 mb-20" <?php echo ( $cs_type == 'iab' ) ? 'style="display:none;"' : ''; ?>>
                                <div class="d-flex align-items-center">
									<?php
									echo render_subcheckbox_input( '_cs_smart_sticky', false, true, $id, false, false, __( 'Smart Sticky', 'consent-magic' ), false, 'switcher-sub-label' ); ?>
                                </div>
                                <p class="mt-5 mb-5"><?php esc_html_e( 'Show the Sticky message only for negative consent for any of the following categories:', 'consent-magic' ); ?>
                                <div class="sticky_categories grid-4-columns ml-40 mt-10">
									<?php
									if ( !empty( $options ) ) {
										foreach ( $options as $option ) {
											$ignore_category = (int) get_term_meta( $option->term_id, 'cs_ignore_this_category', true );
											?>
                                            <div class="mr-20 p-5 <?php echo $ignore_category ? 'dimmy_checkbox' : ''; ?>">
                                                <div class="column-checkbox">
													<?php
													echo render_subcheckbox_input( '_cs_smart_sticky_' . $option->term_id, false, true, $id, false, $ignore_category, $option->name_l, $ignore_category ? 0 : false, 'small-switch' );
													?>
                                                </div>
                                            </div>
										<?php }
									}
									?>
                                </div>
                            </div>

                            <div class="ml-20" <?php echo ( $cs_type == 'iab' ) ? 'style="display:none;"' : ''; ?>>
                                <div class="d-flex align-items-center">
									<?php echo render_subcheckbox_input( '_cs_smart_sticky_mobile', false, true, $id, false, false, __( 'Smart Mobile Sticky', 'consent-magic' ), false, 'switcher-sub-label' ); ?>
                                </div>
                                <p class="mt-5 mb-5"><?php esc_html_e( 'Show the Sticky button only for negative consent for any of the following categories:', 'consent-magic' ); ?></p>

                                <div class="sticky_categories grid-4-columns ml-40">
									<?php
									if ( !empty( $options ) ) {
										foreach ( $options as $option ) {
											$ignore_category = (int) get_term_meta( $option->term_id, 'cs_ignore_this_category', true );
											?>
                                            <div class="mr-20 p-5 <?php echo $ignore_category ? 'dimmy_checkbox' : ''; ?>">
                                                <div class="column-checkbox">
													<?php
													echo render_subcheckbox_input( '_cs_smart_sticky_mobile_' . $option->term_id, false, true, $id, false, $ignore_category, $option->name_l, $ignore_category ? 0 : false, 'small-switch' );
													?>
                                                </div>
                                            </div>
										<?php }
									}
									?>
                                </div>
                            </div>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_mobile_side_sticky', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Mobile Side Sticky Button', 'consent-magic' ); ?></h4>
                            <p><?php esc_html_e( 'Place sticky button on the right side for mobile devices not to overlap the content', 'consent-magic' ); ?></p>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_deny_all_btn', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Deny all button', 'consent-magic' ); ?></h4>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_hide_close_btn', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Hide close button', 'consent-magic' ); ?></h4>
                            <p><?php esc_html_e( 'It will hide the close button, forcing users to express positive or negative consent.', 'consent-magic' ); ?></p>
                        </div>

                        <div class="list-item" <?php echo ( get_post_meta( $id, '_cs_type', true ) != 'ask_before_tracking' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_deny_consent_for_close', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Don\'t show the consent prompt after click on the close button', 'consent-magic' ); ?></h4>
                            <p><?php esc_html_e( 'This action will equivalent with negative consent for all categories', 'consent-magic' ); ?></p>
                        </div>

                        <div class="list-item cs_custom_button_block" <?php echo ( $cs_type == 'just_inform' || $cs_type == 'iab' ) ? 'style="display:none;"' : ''; ?>>
                            <div class="d-flex align-items-center">
								<?php echo render_switcher_input( '_cs_custom_button', false, true, $id ); ?>
                                <h4 class="indicator-label switcher-sub-label"><?php esc_html_e( 'Add custom button', 'consent-magic' ); ?></h4>
                            </div>
                            <p class="mt-5 mb-5"><?php echo sprintf( esc_html__( 'The default text for the custom button is "Minimum recommended". You can edit it from the %s global text settings%s, or add a custom text for this rule.', 'consent-magic' ), '<a href="' . esc_url( get_admin_url( null, 'admin.php?page=consent-magic&tab=cs-text' ) ) . '" target="_blank">', '</a>' ); ?></p>
                            <p class="mt-5 mb-5"><?php esc_html_e( 'The custom button will turn ON the following categories:', 'consent-magic' ); ?></p>

                            <div class="sticky_categories grid-4-columns ml-60">
								<?php
								if ( !empty( $options ) ) {
									foreach ( $options as $option ) {
										$ignore_category = (int) get_term_meta( $option->term_id, 'cs_ignore_this_category', true );
										?>
                                        <div class="mr-20 p-5 <?php echo $ignore_category ? 'dimmy_checkbox' : ''; ?>">
                                            <div class="column-checkbox">
												<?php
												echo render_subcheckbox_input( '_cs_custom_button_' . $option->term_id, false, true, $id, false, $ignore_category, $option->name_l, $ignore_category ? 0 : false, 'small-switch' );
												?>
                                            </div>
                                        </div>
									<?php }
								}
								?>
                            </div>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item">
							<?php echo render_switcher_input( '_cs_privacy_link', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"
                                style="margin: 0;"><?php esc_html_e( 'Privacy link', 'consent-magic' ); ?></h4>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_block_content', false, true, $id, false, false, esc_html__( 'Block scroll', 'consent-magic' ) ); ?>
                            <p><?php esc_html_e( 'Block scroll until the visitor interacts with the consent message.', 'consent-magic' ); ?></p>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'iab' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_close_on_scroll', false, true, $id ); ?>
                            <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Close on Scroll', 'consent-magic' ); ?></h4>

                            <div class="cs-line cs_showing_line mb-30 mt-30" <?php echo ( $cs_type != 'just_inform' ) ? 'style="display:none;"' : ''; ?>></div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type == 'just_inform' ) ? 'style="display:none;"' : ''; ?>>
							<?php
							if ( isFbWooActivated() && !isPYSActivated() && (int) ConsentMagic()->getOption( 'cs_fb_woo_capi_enabled' ) === 1 && (int) ConsentMagic()->getOption( 'cs_enable_site_cache' ) === 0 ): ?>
                                <span class="dimmy_checkbox">
                                    <?php echo render_switcher_input( '_cs_refresh_after_consent', false, true, $id, false, true, esc_html__( 'Refresh page after consent', 'consent-magic' ), true ); ?>
                                </span>
                                <p><?php esc_html_e( 'Facebook for WooCommerce CAPI events control is ON, we need to refresh the page after the user interacts with the consent message.', 'consent-magic' ); ?></p>
							<?php else: ?>
								<?php echo render_switcher_input( '_cs_refresh_after_consent', false, true, $id, false, false, esc_html__( 'Refresh page after consent', 'consent-magic' ) ); ?>
                                <p><?php esc_html_e( 'If enabled, the plugin will refresh the page when the user interacts with the consent message (accept, reject).', 'consent-magic' ); ?></p>
							<?php endif; ?>

                            <div class="cs-line cs_showing_line mb-30 mt-30" <?php echo $cs_type == 'inform_and_opiout' ? 'style="display:none;"' : ''; ?>></div>
                        </div>

                        <div class="list-item" <?php echo $cs_type != 'inform_and_opiout' ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_showing_rule_until_express_consent', false, true, $id, false, false, __( 'Show the consent message until the visitor interacts with it', 'consent-magic' ) ); ?>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item" <?php echo ( $cs_type != 'ask_before_tracking' ) ? 'style="display:none;"' : ''; ?>>
							<?php echo render_switcher_input( '_cs_track_analytics', false, true, $id, false, false, __( 'Track Analytics cookies and scripts before consent is expressed', 'consent-magic' ) ); ?>
                            <p><?php esc_html_e( '"Necessary" cookies and scripts will work every time', 'consent-magic' ); ?></p>
                            <p><?php esc_html_e( '"Marketing" cookies and scripts will work only after consent is given', 'consent-magic' ); ?></p>
                            <p><?php esc_html_e( 'You have more options under ', 'consent-magic' ); ?><a
                                        href="<?php echo esc_url( get_admin_url() . 'admin.php?page=consent-magic&tab=cs-script-blocking' ); ?>"
                                        class="link-to-nav-tab"><?php esc_html_e( 'Script Blocking', 'consent-magic' ); ?></a>
                            </p>

                            <div class="cs-line mb-30 mt-30"></div>
                        </div>

                        <div class="list-item">
							<?php echo render_switcher_input( '_excluded_from_consent_storing', false, true, $id, false, false, esc_html__( 'Excluded from consent storing', 'consent-magic' ) ); ?>
                        </div>
                    </div>

                    <div class="rules-wrap">
                        <div class="row headline">
                            <div class="col-12">
                                <h3 class="indicator-label"><?php esc_html_e( 'Content:', 'consent-magic' ); ?></h3>
                            </div>

                            <div class="col-12 list-item cs_design_type_wrap" <?php echo $cs_type == 'just_inform' ? 'style="display:none;"' : ''; ?>>
								<?php renderSelectInput_meta( '_cs_design_type', $id, renderCSDesignTypeOptions(), true, false, $cs_type == 'iab' ); ?>
                            </div>

                            <div class="col-12 list-item">
								<?php renderSelectInput_meta( '_cs_theme', $id, get_custom_theme_list(), true ); ?>
                            </div>

                            <div class="col-12 list-item">
								<?php renderSelectInput_meta( '_cs_bars_type', $id, renderCSBarTypeOptions(), true, false, $design_type === 'single' ); ?>
                            </div>

                            <div class="col-12 list-item cs_bars_position_wrap" <?php echo ( ( ( get_post_meta( $id, '_cs_bars_type', true ) == 'bar_small' ) || ( get_post_meta( $id, '_cs_bars_type', true ) == 'bar_large' ) ) && $design_type !== 'single' ) ? '' : 'style="display:none;"'; ?>>
								<?php renderSelectInput_meta( '_cs_bars_position', $id, renderCSBarPositionOptions(), true ); ?>
                            </div>

                            <div class="list-item col-12 cs_top_push_wrap" style="display: none;">
								<?php echo render_switcher_input( '_cs_top_push', false, true, $id ); ?>
                                <h4 class="indicator-label switcher-label"><?php esc_html_e( 'Top bar: push content down', 'consent-magic' ); ?></h4>
                            </div>
                        </div>

                        <div class="cs_custom_text" <?php echo ( $cs_type == 'iab' ) ? 'style="display:none;"' : ''; ?>>
                            <div class="list-item">
								<?php echo render_switcher_input( '_cs_custom_text', false, true, $id, false, false, __( 'Custom text', 'consent-magic' ) ); ?>
                            </div>

                            <div class="custom_text_wrap" <?php echo ( get_post_meta( $id, '_cs_custom_text', true ) == '0' ) ? 'style="display:none;"' : ''; ?>>
                                <div class="card">
                                    <div class="card-header">
                                        <div class="row">
                                            <div class="col">
                                                <h3 class="card_title"><?php esc_html_e( 'Small bar or popup', 'consent-magic' ); ?></h3>
                                                <p><?php esc_html_e( 'This text is used when "small bar" or "small popup" are selected', 'consent-magic' ); ?></p>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link card-collapse">
													<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>
									<?php
									$lang_list = get_post_meta( $id, '_cs_text_in_small_bar_popup_lang', true );
									if ( is_array( $lang_list ) ) {
										$key_lang   = array_search( $current_lang, $lang_list );
										$attr_value = ConsentMagic()->getLangOption( '_cs_text_in_small_bar_popup', $current_lang, true );
										if ( empty( $attr_value ) || $key_lang === false ) {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										} else {
											$display_lang = $lang_list[ $key_lang ];
										}
									} else {
										$display_lang = CMPRO_DEFAULT_LANGUAGE;
									}
									?>
                                    <div class="card-body" style="display: none;">
                                        <div class="cart_line_item input_row_default">
                                            <div class="row cs_data_render_wrap cs_data_render_wrap_editor">
                                                <div class="col-12">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderWpEditor( '_cs_text_in_small_bar_popup', $display_lang, 'js-control-element', true, $id ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="sub-card">
                                            <div class="sub-card-header">
                                                <div class="row">
                                                    <div class="col">
														<?php render_additional_lang_button( 'Small bar or popup' ); ?>
                                                    </div>

                                                    <div class="col-2 right-aligned">
                                                        <button type="button" class="btn btn-link sub-card-collapse">
															<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                    class="icon-down"></i>
                                                        </button>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card-body" style="display: none;">
                                                <div class="language_list">
													<?php
													if ( !empty( $lang_list ) ) :
														foreach ( $lang_list as $lang ) :
															if ( $lang != $display_lang ) :?>
                                                                <div class="row cart_line_item"
                                                                     style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                    <div class="col-1 cs-delete-lang-wrap">
                                                                        <span class="icon-minus cs-delete-lang"></span>
                                                                    </div>

                                                                    <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                        <div class="col-12">
                                                                            <div class="row input_row cs_data_render">
                                                                                <div class="cs_data_render_wrap">
																					<?php renderWpEditor( '_cs_text_in_small_bar_popup', $lang, 'js-control-element', true, $id ); ?>
                                                                                </div>
                                                                            </div>

                                                                            <div class="row cs_data_render_buttons">
																				<?php renderSelectLanguages( false, '_cs_text_in_small_bar_popup', $lang, false, $id, 'renderWpEditor', true, '250px' ); ?>
                                                                            </div>
                                                                        </div>
                                                                    </div>
                                                                </div>
															<?php endif;
														endforeach;
													endif;
													?>
                                                </div>

                                                <div class="add_new_lang_wrap">
													<?php render_add_lang_button( '_cs_text_in_small_bar_popup', 'renderWpEditor' ); ?>
                                                    <div style="display: none" class="add_new_lang">
                                                        <div class="row cart_line_item">
                                                            <div class="col-1 cs-delete-lang-wrap">
                                                                <span class="icon-minus cs-delete-lang"></span>
                                                            </div>

                                                            <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                <div class="col-12">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_text_in_small_bar_popup', $id, 'renderWpEditor', true, '250px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="row cs_data_render_buttons">
                                            <button type="button" name="update_admin_settings_form"
                                                    onClick="return cs_store_settings_btn_click(this.name)"
                                                    class="btn btn-blue btn-right btn_single_save">
                                                <i class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?>
                                            </button>
                                        </div>
                                    </div>
                                </div>

                                <div class="card">
                                    <div class="card-header">
                                        <div class="row">
                                            <div class="col">
                                                <h3 class="card_title"><?php esc_html_e( 'Large bar or popup', 'consent-magic' ); ?></h3>
                                                <p><?php esc_html_e( 'This text is used when "large bar" or "large popup" are selected', 'consent-magic' ); ?></p>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link card-collapse">
													<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>
									<?php
									$lang_list = get_post_meta( $id, '_cs_text_in_large_bar_popup_lang', true );
									if ( is_array( $lang_list ) ) {
										$key_lang   = array_search( $current_lang, $lang_list );
										$attr_value = ConsentMagic()->getLangOption( '_cs_text_in_large_bar_popup', $current_lang, true );
										if ( empty( $attr_value ) || $key_lang === false ) {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										} else {
											$display_lang = $lang_list[ $key_lang ];
										}
									} else {
										$display_lang = CMPRO_DEFAULT_LANGUAGE;
									}
									?>
                                    <div class="card-body" style="display: none;">
                                        <div class="cart_line_item input_row_default">
                                            <div class="row cs_data_render_wrap cs_data_render_wrap_editor">
                                                <div class="col-12">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderWpEditor( '_cs_text_in_large_bar_popup', $display_lang, 'js-control-element', true, $id ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="sub-card">
                                            <div class="sub-card-header">
                                                <div class="row">
                                                    <div class="col">
														<?php render_additional_lang_button( 'Large bar or popup' ); ?>
                                                    </div>

                                                    <div class="col-2 right-aligned">
                                                        <button type="button" class="btn btn-link sub-card-collapse">
															<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                    class="icon-down"></i>
                                                        </button>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card-body" style="display: none;">
                                                <div class="language_list">
													<?php
													if ( !empty( $lang_list ) ) :
														foreach ( $lang_list as $lang ) :
															if ( $lang != $display_lang ) :?>
                                                                <div class="row cart_line_item"
                                                                     style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                    <div class="col-1 cs-delete-lang-wrap">
                                                                        <span class="icon-minus cs-delete-lang"></span>
                                                                    </div>

                                                                    <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                        <div class="col-12">
                                                                            <div class="row input_row cs_data_render">
                                                                                <div class="cs_data_render_wrap">
																					<?php renderWpEditor( '_cs_text_in_large_bar_popup', $lang, 'js-control-element', true, $id ); ?>
                                                                                </div>
                                                                            </div>

                                                                            <div class="row cs_data_render_buttons">
																				<?php renderSelectLanguages( false, '_cs_text_in_large_bar_popup', $lang, false, $id, 'renderWpEditor', true, '250px' ); ?>
                                                                            </div>
                                                                        </div>
                                                                    </div>
                                                                </div>
															<?php endif;
														endforeach;
													endif;
													?>
                                                </div>

                                                <div class="add_new_lang_wrap">
													<?php render_add_lang_button( '_cs_text_in_large_bar_popup', 'renderWpEditor' ); ?>
                                                    <div style="display: none" class="add_new_lang">
                                                        <div class="row cart_line_item">
                                                            <div class="col-1 cs-delete-lang-wrap">
                                                                <span class="icon-minus cs-delete-lang"></span>
                                                            </div>

                                                            <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                <div class="col-12">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_text_in_large_bar_popup', $id, 'renderWpEditor', true, '250px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="row cs_data_render_buttons">
                                            <button type="button" name="update_admin_settings_form"
                                                    onClick="return cs_store_settings_btn_click(this.name)"
                                                    class="btn btn-blue btn-right btn_single_save">
                                                <i class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?>
                                            </button>
                                        </div>
                                    </div>
                                </div>

                                <div class="card">
                                    <div class="card-header">
                                        <div class="row">
                                            <div class="col">
                                                <h3 class="card_title"><?php esc_html_e( "Button's text", 'consent-magic' ); ?></h3>
                                                <p><?php esc_html_e( 'This text is used on buttons on all types of bars and popups.', 'consent-magic' ); ?></p>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link card-collapse">
													<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="card-body" style="display: none;">
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_allow_all_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_allow_all', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Allow all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_allow_all', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Allow all' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_allow_all', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_allow_all', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_allow_all', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_allow_all', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_custom_button_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_custom_button', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Custom button:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_custom_button', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Custom button' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_custom_button', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_custom_button', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_custom_button', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_custom_button', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_disable_all_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_disable_all', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Disable all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_disable_all', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Disable all' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_disable_all', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_disable_all', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_disable_all', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_disable_all', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_customize_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_customize', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Customize:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_customize', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Customize' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_customize', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>
                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_customize', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_customize', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_customize', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_privacy_cookie_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_privacy_cookie', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Privacy & Cookies:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_privacy_cookie', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Privacy & Cookies' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_privacy_cookie', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_privacy_cookie', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_privacy_cookie', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_privacy_cookie', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_sticky_cookie_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_sticky_cookie', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Sticky:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_sticky_cookie', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Sticky' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_sticky_cookie', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_sticky_cookie', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_sticky_cookie', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_sticky_cookie', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div>
                                            <button type="button" name="update_admin_settings_form"
                                                    onClick="return cs_store_settings_btn_click(this.name)"
                                                    class="btn btn-blue btn-right btn_single_save">
                                                <i class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?>
                                            </button>
                                        </div>
                                    </div>
                                </div>

                                <div class="card">
                                    <div class="card-header">
                                        <div class="row">
                                            <div class="col">
                                                <h3 class="card_title"><?php esc_html_e( 'Options popups', 'consent-magic' ); ?></h3>
                                                <p><?php esc_html_e( 'Customize the content of the options popup.', 'consent-magic' ); ?></p>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link card-collapse">
													<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="card-body" style="display: none;">
										<?php
										$lang_list = get_post_meta( $id, '_cs_text_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_text_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item input_row_default">
                                            <div class="row cs_data_render_wrap cs_data_render_wrap_editor">
                                                <div class="col-12">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderWpEditor( '_cs_text_in_options_popup', $display_lang, 'js-control-element', true, $id ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Options popups' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) : ?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor"
                                                                             style="margin-bottom: 5px;">
                                                                            <div class="col-12">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderWpEditor( '_cs_text_in_options_popup', $lang, 'js-control-element', true, $id ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_text_in_options_popup', $lang, false, $id, 'renderWpEditor', true, '250px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_text_in_options_popup', 'renderWpEditor' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                    <div class="col-12">
                                                                        <div class="row input_row cs_data_render">
                                                                        </div>
                                                                        <div class="row cs_data_render_buttons">
																			<?php renderSelectLanguagesNew( false, '_cs_text_in_options_popup', $id, 'renderWpEditor', true, '250px' ); ?>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

										<?php
										$lang_list = get_post_meta( $id, '_cs_title_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_title_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Title:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_title_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Title' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_title_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_title_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_title_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_title_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_subtitle_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_subtitle_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Subtitle:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_subtitle_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Subtitle' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_subtitle_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_subtitle_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>
                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_subtitle_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_subtitle_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_allow_all_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_allow_all_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Allow all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_allow_all_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Allow all' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_allow_all_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_allow_all_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_allow_all_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_allow_all_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_disable_all_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_disable_all_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Disable all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_disable_all_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Disable all' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_disable_all_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_disable_all_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_disable_all_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_disable_all_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_confirm_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_confirm_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Confirm my choices:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_confirm_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Confirm my choices' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_confirm_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_confirm_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_confirm_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_confirm_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div><?php
										$lang_list = get_post_meta( $id, '_cs_always_on_in_options_popup_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_always_on_in_options_popup', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Always ON:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_always_on_in_options_popup', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Always ON' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_always_on_in_options_popup', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_always_on_in_options_popup', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_always_on_in_options_popup', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_always_on_in_options_popup', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div>
                                            <button type="button" name="update_admin_settings_form"
                                                    onClick="return cs_store_settings_btn_click(this.name)"
                                                    class="btn btn-blue btn-right btn_single_save">
                                                <i class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?>
                                            </button>
                                        </div>
                                    </div>
                                </div>

                                <div class="card">
                                    <div class="card-header">
                                        <div class="row">
                                            <div class="col">
                                                <h3 class="card_title"><?php esc_html_e( 'Single-step', 'consent-magic' ); ?></h3>
                                                <p><?php esc_html_e( 'Customize the content of the Single-step.', 'consent-magic' ); ?></p>
                                            </div>

                                            <div class="col-2 right-aligned">
                                                <button type="button" class="btn btn-link card-collapse">
													<?php esc_html_e( 'Edit', 'consent-magic' ); ?> <i
                                                            class="icon-down"></i>
                                                </button>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="card-body" style="display: none;">
										<?php
										$lang_list = get_post_meta( $id, '_cs_text_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_text_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item input_row_default">
                                            <div class="row cs_data_render_wrap cs_data_render_wrap_editor">
                                                <div class="col-12">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderWpEditor( '_cs_text_in_single_design', $display_lang, 'js-control-element', true, $id ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Options popups' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) : ?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor"
                                                                             style="margin-bottom: 5px;">
                                                                            <div class="col-12">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderWpEditor( '_cs_text_in_single_design', $lang, 'js-control-element', true, $id ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_text_in_single_design', $lang, false, $id, 'renderWpEditor', true, '250px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_text_in_single_design', 'renderWpEditor' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_editor">
                                                                    <div class="col-12">
                                                                        <div class="row input_row cs_data_render">
                                                                        </div>
                                                                        <div class="row cs_data_render_buttons">
																			<?php renderSelectLanguagesNew( false, '_cs_text_in_single_design', $id, 'renderWpEditor', true, '250px' ); ?>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

										<?php
										$lang_list = get_post_meta( $id, '_cs_title_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_title_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Title:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_title_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Title' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_title_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_title_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_title_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_title_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_subtitle_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_subtitle_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Subtitle:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_subtitle_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Subtitle' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_subtitle_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_subtitle_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>
                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_subtitle_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_subtitle_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_allow_all_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_allow_all_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Allow all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_allow_all_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Allow all' ); ?>
                                                        </div>
                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_allow_all_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_allow_all_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_allow_all_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_allow_all_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_disable_all_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_disable_all_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Disable all:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_disable_all_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Disable all' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>
                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_disable_all_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_disable_all_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_disable_all_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_disable_all_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_confirm_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_confirm_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Confirm my choices:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_confirm_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Confirm my choices' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_confirm_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_confirm_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_confirm_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_confirm_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

										<?php
										$lang_list = get_post_meta( $id, '_cs_btn_text_custom_button_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_btn_text_custom_button_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Custom button:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_btn_text_custom_button_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Custom button' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_btn_text_custom_button_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_btn_text_custom_button_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_btn_text_custom_button_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_btn_text_custom_button_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

										<?php
										$lang_list = get_post_meta( $id, '_cs_always_on_in_single_design_lang', true );
										if ( is_array( $lang_list ) ) {
											$key_lang   = array_search( $current_lang, $lang_list );
											$attr_value = ConsentMagic()->getLangOption( '_cs_always_on_in_single_design', $current_lang, true );
											if ( empty( $attr_value ) || $key_lang === false ) {
												$display_lang = CMPRO_DEFAULT_LANGUAGE;
											} else {
												$display_lang = $lang_list[ $key_lang ];
											}
										} else {
											$display_lang = CMPRO_DEFAULT_LANGUAGE;
										}
										?>
                                        <div class="cart_line_item">
                                            <div class="label_row">
                                                <h4><?php esc_html_e( 'Always ON:', 'consent-magic' ); ?></h4>
                                            </div>

                                            <div class="input_row input_row_default">
                                                <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                    <div class="row input_row cs_data_render">
                                                        <div class="cs_data_render_wrap">
															<?php renderTextInput( '_cs_always_on_in_single_design', $id, $display_lang, true, '', 'js-control-element' ); ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>

                                            <div class="sub-card sub-card-inputs">
                                                <div class="sub-card-header">
                                                    <div class="row">
                                                        <div class="col">
															<?php render_additional_lang_button( 'Always ON' ); ?>
                                                        </div>

                                                        <div class="col-2 right-aligned">
                                                            <button type="button"
                                                                    class="btn btn-link sub-card-collapse">
																<?php esc_html_e( 'Show', 'consent-magic' ); ?> <i
                                                                        class="icon-down"></i>
                                                            </button>
                                                        </div>
                                                    </div>
                                                </div>

                                                <div class="sub-card-body" style="display: none;">
                                                    <div class="language_list">
														<?php
														if ( !empty( $lang_list ) ) :
															foreach ( $lang_list as $lang ) :
																if ( $lang != $display_lang ) :?>
                                                                    <div class="row cart_line_item"
                                                                         style="<?php echo isset( $cs_language_availability[ $lang ] ) && $cs_language_availability[ $lang ] == 0 ? 'display:none;' : '' ?>">
                                                                        <div class="col-1 cs-delete-lang-wrap">
                                                                            <span class="icon-minus cs-delete-lang"></span>
                                                                        </div>

                                                                        <div class="col-11 input_row">
                                                                            <div class="row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                                <div class="row input_row cs_data_render">
                                                                                    <div class="cs_data_render_wrap">
																						<?php renderTextInput( '_cs_always_on_in_single_design', $id, $lang, true, '', 'js-control-element' ); ?>
                                                                                    </div>
                                                                                </div>

                                                                                <div class="row cs_data_render_buttons">
																					<?php renderSelectLanguages( false, '_cs_always_on_in_single_design', $lang, false, $id, 'renderTextInput', true, '240px' ); ?>
                                                                                </div>
                                                                            </div>
                                                                        </div>
                                                                    </div>
																<?php endif;
															endforeach;
														endif;
														?>
                                                    </div>

                                                    <div class="add_new_lang_wrap">
														<?php render_add_lang_button( '_cs_always_on_in_single_design', 'renderTextInput' ); ?>
                                                        <div style="display: none" class="add_new_lang">
                                                            <div class="row cart_line_item">
                                                                <div class="col-1 cs-delete-lang-wrap">
                                                                    <span class="icon-minus cs-delete-lang"></span>
                                                                </div>

                                                                <div class="col-11 row cs_data_render_wrap cs_data_render_wrap_text_input">
                                                                    <div class="row input_row cs_data_render">
                                                                    </div>
                                                                    <div class="row cs_data_render_buttons">
																		<?php renderSelectLanguagesNew( false, '_cs_always_on_in_single_design', $id, 'renderTextInput', true, '240px' ); ?>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>

                                        <div>
                                            <button type="button" name="update_admin_settings_form"
                                                    onClick="return cs_store_settings_btn_click(this.name)"
                                                    class="btn btn-blue btn-right btn_single_save">
                                                <i class="icon-save"></i> <?php esc_html_e( 'Save', 'consent-magic' ); ?>
                                            </button>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="list-item headline">
                                <div>
                                    <p><?php esc_html_e( 'You can change the default text from the ', 'consent-magic' ); ?>
                                        <a
                                                href="<?php echo esc_url( get_admin_url() . 'admin.php?page=consent-magic&tab=cs-text' ); ?>"
                                                class="link-to-nav-tab"><?php esc_html_e( 'Text Section', 'consent-magic' ); ?></a>
                                    </p>
                                </div>
                            </div>
                        </div>
                    </div>

					<?php
					//save button
					include CMPRO_PLUGIN_VIEWS_PATH . "admin/buttons/admin-rules-save-button.php";
					?>
                </div>
            </div>
        </div>
    </form>
</div>